
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.AccelLabel
    ( 

-- * Exported types
    AccelLabel(..)                          ,
    AccelLabelK                             ,
    toAccelLabel                            ,
    noAccelLabel                            ,


 -- * Methods
-- ** accelLabelGetAccel
    accelLabelGetAccel                      ,


-- ** accelLabelGetAccelWidget
    accelLabelGetAccelWidget                ,


-- ** accelLabelGetAccelWidth
    accelLabelGetAccelWidth                 ,


-- ** accelLabelNew
    accelLabelNew                           ,


-- ** accelLabelRefetch
    accelLabelRefetch                       ,


-- ** accelLabelSetAccel
    accelLabelSetAccel                      ,


-- ** accelLabelSetAccelClosure
    accelLabelSetAccelClosure               ,


-- ** accelLabelSetAccelWidget
    accelLabelSetAccelWidget                ,




 -- * Properties
-- ** AccelClosure
    AccelLabelAccelClosurePropertyInfo      ,
    constructAccelLabelAccelClosure         ,
    getAccelLabelAccelClosure               ,
    setAccelLabelAccelClosure               ,


-- ** AccelWidget
    AccelLabelAccelWidgetPropertyInfo       ,
    constructAccelLabelAccelWidget          ,
    getAccelLabelAccelWidget                ,
    setAccelLabelAccelWidget                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject
import qualified GI.Gdk as Gdk

newtype AccelLabel = AccelLabel (ForeignPtr AccelLabel)
foreign import ccall "gtk_accel_label_get_type"
    c_gtk_accel_label_get_type :: IO GType

type instance ParentTypes AccelLabel = AccelLabelParentTypes
type AccelLabelParentTypes = '[Label, Misc, Widget, GObject.Object, Atk.ImplementorIface, Buildable]

instance GObject AccelLabel where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_accel_label_get_type
    

class GObject o => AccelLabelK o
instance (GObject o, IsDescendantOf AccelLabel o) => AccelLabelK o

toAccelLabel :: AccelLabelK o => o -> IO AccelLabel
toAccelLabel = unsafeCastTo AccelLabel

noAccelLabel :: Maybe AccelLabel
noAccelLabel = Nothing

--- XXX Duplicated object with different types:
  --- Name {namespace = "Gtk", name = "Label"} -> Property {propName = "xalign", propType = TBasicType TFloat, propFlags = [PropertyReadable,PropertyWritable], propTransfer = TransferNothing, propDeprecated = Nothing}
  --- Name {namespace = "Gtk", name = "Misc"} -> Property {propName = "xalign", propType = TBasicType TFloat, propFlags = [PropertyReadable,PropertyWritable], propTransfer = TransferNothing, propDeprecated = Just (DeprecationInfo {deprecatedSinceVersion = Just "3.14", deprecationMessage = Just "Use gtk_widget_set_halign() instead. If you are using\n  #GtkLabel, use #GtkLabel:xalign instead."})}
--- XXX Duplicated object with different types:
  --- Name {namespace = "Gtk", name = "Label"} -> Property {propName = "yalign", propType = TBasicType TFloat, propFlags = [PropertyReadable,PropertyWritable], propTransfer = TransferNothing, propDeprecated = Nothing}
  --- Name {namespace = "Gtk", name = "Misc"} -> Property {propName = "yalign", propType = TBasicType TFloat, propFlags = [PropertyReadable,PropertyWritable], propTransfer = TransferNothing, propDeprecated = Just (DeprecationInfo {deprecatedSinceVersion = Just "3.14", deprecationMessage = Just "Use gtk_widget_set_valign() instead. If you are using\n  #GtkLabel, use #GtkLabel:yalign instead."})}
-- VVV Prop "accel-closure"
   -- Type: TInterface "GObject" "Closure"
   -- Flags: [PropertyReadable,PropertyWritable]

getAccelLabelAccelClosure :: (MonadIO m, AccelLabelK o) => o -> m Closure
getAccelLabelAccelClosure obj = liftIO $ getObjectPropertyBoxed obj "accel-closure" Closure

setAccelLabelAccelClosure :: (MonadIO m, AccelLabelK o) => o -> Closure -> m ()
setAccelLabelAccelClosure obj val = liftIO $ setObjectPropertyBoxed obj "accel-closure" val

constructAccelLabelAccelClosure :: Closure -> IO ([Char], GValue)
constructAccelLabelAccelClosure val = constructObjectPropertyBoxed "accel-closure" val

data AccelLabelAccelClosurePropertyInfo
instance AttrInfo AccelLabelAccelClosurePropertyInfo where
    type AttrAllowedOps AccelLabelAccelClosurePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint AccelLabelAccelClosurePropertyInfo = (~) Closure
    type AttrBaseTypeConstraint AccelLabelAccelClosurePropertyInfo = AccelLabelK
    type AttrGetType AccelLabelAccelClosurePropertyInfo = Closure
    type AttrLabel AccelLabelAccelClosurePropertyInfo = "AccelLabel::accel-closure"
    attrGet _ = getAccelLabelAccelClosure
    attrSet _ = setAccelLabelAccelClosure
    attrConstruct _ = constructAccelLabelAccelClosure

-- VVV Prop "accel-widget"
   -- Type: TInterface "Gtk" "Widget"
   -- Flags: [PropertyReadable,PropertyWritable]

getAccelLabelAccelWidget :: (MonadIO m, AccelLabelK o) => o -> m Widget
getAccelLabelAccelWidget obj = liftIO $ getObjectPropertyObject obj "accel-widget" Widget

setAccelLabelAccelWidget :: (MonadIO m, AccelLabelK o, WidgetK a) => o -> a -> m ()
setAccelLabelAccelWidget obj val = liftIO $ setObjectPropertyObject obj "accel-widget" val

constructAccelLabelAccelWidget :: (WidgetK a) => a -> IO ([Char], GValue)
constructAccelLabelAccelWidget val = constructObjectPropertyObject "accel-widget" val

data AccelLabelAccelWidgetPropertyInfo
instance AttrInfo AccelLabelAccelWidgetPropertyInfo where
    type AttrAllowedOps AccelLabelAccelWidgetPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint AccelLabelAccelWidgetPropertyInfo = WidgetK
    type AttrBaseTypeConstraint AccelLabelAccelWidgetPropertyInfo = AccelLabelK
    type AttrGetType AccelLabelAccelWidgetPropertyInfo = Widget
    type AttrLabel AccelLabelAccelWidgetPropertyInfo = "AccelLabel::accel-widget"
    attrGet _ = getAccelLabelAccelWidget
    attrSet _ = setAccelLabelAccelWidget
    attrConstruct _ = constructAccelLabelAccelWidget

type instance AttributeList AccelLabel = AccelLabelAttributeList
type AccelLabelAttributeList = ('[ '("accel-closure", AccelLabelAccelClosurePropertyInfo), '("accel-widget", AccelLabelAccelWidgetPropertyInfo), '("angle", LabelAnglePropertyInfo), '("app-paintable", WidgetAppPaintablePropertyInfo), '("attributes", LabelAttributesPropertyInfo), '("can-default", WidgetCanDefaultPropertyInfo), '("can-focus", WidgetCanFocusPropertyInfo), '("composite-child", WidgetCompositeChildPropertyInfo), '("cursor-position", LabelCursorPositionPropertyInfo), '("double-buffered", WidgetDoubleBufferedPropertyInfo), '("ellipsize", LabelEllipsizePropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("has-default", WidgetHasDefaultPropertyInfo), '("has-focus", WidgetHasFocusPropertyInfo), '("has-tooltip", WidgetHasTooltipPropertyInfo), '("height-request", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpand-set", WidgetHexpandSetPropertyInfo), '("is-focus", WidgetIsFocusPropertyInfo), '("justify", LabelJustifyPropertyInfo), '("label", LabelLabelPropertyInfo), '("lines", LabelLinesPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("margin-bottom", WidgetMarginBottomPropertyInfo), '("margin-end", WidgetMarginEndPropertyInfo), '("margin-left", WidgetMarginLeftPropertyInfo), '("margin-right", WidgetMarginRightPropertyInfo), '("margin-start", WidgetMarginStartPropertyInfo), '("margin-top", WidgetMarginTopPropertyInfo), '("max-width-chars", LabelMaxWidthCharsPropertyInfo), '("mnemonic-keyval", LabelMnemonicKeyvalPropertyInfo), '("mnemonic-widget", LabelMnemonicWidgetPropertyInfo), '("name", WidgetNamePropertyInfo), '("no-show-all", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("pattern", LabelPatternPropertyInfo), '("receives-default", WidgetReceivesDefaultPropertyInfo), '("scale-factor", WidgetScaleFactorPropertyInfo), '("selectable", LabelSelectablePropertyInfo), '("selection-bound", LabelSelectionBoundPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("single-line-mode", LabelSingleLineModePropertyInfo), '("style", WidgetStylePropertyInfo), '("tooltip-markup", WidgetTooltipMarkupPropertyInfo), '("tooltip-text", WidgetTooltipTextPropertyInfo), '("track-visited-links", LabelTrackVisitedLinksPropertyInfo), '("use-markup", LabelUseMarkupPropertyInfo), '("use-underline", LabelUseUnderlinePropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpand-set", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("width-chars", LabelWidthCharsPropertyInfo), '("width-request", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo), '("wrap", LabelWrapPropertyInfo), '("wrap-mode", LabelWrapModePropertyInfo), '("xpad", MiscXpadPropertyInfo), '("ypad", MiscYpadPropertyInfo)] :: [(Symbol, *)])

type instance SignalList AccelLabel = AccelLabelSignalList
type AccelLabelSignalList = ('[ '("accel-closures-changed", WidgetAccelClosuresChangedSignalInfo), '("activate-current-link", LabelActivateCurrentLinkSignalInfo), '("activate-link", LabelActivateLinkSignalInfo), '("button-press-event", WidgetButtonPressEventSignalInfo), '("button-release-event", WidgetButtonReleaseEventSignalInfo), '("can-activate-accel", WidgetCanActivateAccelSignalInfo), '("child-notify", WidgetChildNotifySignalInfo), '("composited-changed", WidgetCompositedChangedSignalInfo), '("configure-event", WidgetConfigureEventSignalInfo), '("copy-clipboard", LabelCopyClipboardSignalInfo), '("damage-event", WidgetDamageEventSignalInfo), '("delete-event", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroy-event", WidgetDestroyEventSignalInfo), '("direction-changed", WidgetDirectionChangedSignalInfo), '("drag-begin", WidgetDragBeginSignalInfo), '("drag-data-delete", WidgetDragDataDeleteSignalInfo), '("drag-data-get", WidgetDragDataGetSignalInfo), '("drag-data-received", WidgetDragDataReceivedSignalInfo), '("drag-drop", WidgetDragDropSignalInfo), '("drag-end", WidgetDragEndSignalInfo), '("drag-failed", WidgetDragFailedSignalInfo), '("drag-leave", WidgetDragLeaveSignalInfo), '("drag-motion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enter-notify-event", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("event-after", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focus-in-event", WidgetFocusInEventSignalInfo), '("focus-out-event", WidgetFocusOutEventSignalInfo), '("grab-broken-event", WidgetGrabBrokenEventSignalInfo), '("grab-focus", WidgetGrabFocusSignalInfo), '("grab-notify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchy-changed", WidgetHierarchyChangedSignalInfo), '("key-press-event", WidgetKeyPressEventSignalInfo), '("key-release-event", WidgetKeyReleaseEventSignalInfo), '("keynav-failed", WidgetKeynavFailedSignalInfo), '("leave-notify-event", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("map-event", WidgetMapEventSignalInfo), '("mnemonic-activate", WidgetMnemonicActivateSignalInfo), '("motion-notify-event", WidgetMotionNotifyEventSignalInfo), '("move-cursor", LabelMoveCursorSignalInfo), '("move-focus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parent-set", WidgetParentSetSignalInfo), '("populate-popup", LabelPopulatePopupSignalInfo), '("popup-menu", WidgetPopupMenuSignalInfo), '("property-notify-event", WidgetPropertyNotifyEventSignalInfo), '("proximity-in-event", WidgetProximityInEventSignalInfo), '("proximity-out-event", WidgetProximityOutEventSignalInfo), '("query-tooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("screen-changed", WidgetScreenChangedSignalInfo), '("scroll-event", WidgetScrollEventSignalInfo), '("selection-clear-event", WidgetSelectionClearEventSignalInfo), '("selection-get", WidgetSelectionGetSignalInfo), '("selection-notify-event", WidgetSelectionNotifyEventSignalInfo), '("selection-received", WidgetSelectionReceivedSignalInfo), '("selection-request-event", WidgetSelectionRequestEventSignalInfo), '("show", WidgetShowSignalInfo), '("show-help", WidgetShowHelpSignalInfo), '("size-allocate", WidgetSizeAllocateSignalInfo), '("state-changed", WidgetStateChangedSignalInfo), '("state-flags-changed", WidgetStateFlagsChangedSignalInfo), '("style-set", WidgetStyleSetSignalInfo), '("style-updated", WidgetStyleUpdatedSignalInfo), '("touch-event", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmap-event", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibility-notify-event", WidgetVisibilityNotifyEventSignalInfo), '("window-state-event", WidgetWindowStateEventSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method AccelLabel::new
-- method type : Constructor
-- Args : [Arg {argName = "string", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "string", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "AccelLabel"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_new" gtk_accel_label_new :: 
    CString ->                              -- string : TBasicType TUTF8
    IO (Ptr AccelLabel)


accelLabelNew ::
    (MonadIO m) =>
    T.Text ->                               -- string
    m AccelLabel
accelLabelNew string = liftIO $ do
    string' <- textToCString string
    result <- gtk_accel_label_new string'
    checkUnexpectedReturnNULL "gtk_accel_label_new" result
    result' <- (newObject AccelLabel) result
    freeMem string'
    return result'

-- method AccelLabel::get_accel
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accelerator_key", argType = TBasicType TUInt32, direction = DirectionOut, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferEverything},Arg {argName = "accelerator_mods", argType = TInterface "Gdk" "ModifierType", direction = DirectionOut, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferEverything}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_get_accel" gtk_accel_label_get_accel :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    Ptr Word32 ->                           -- accelerator_key : TBasicType TUInt32
    Ptr CUInt ->                            -- accelerator_mods : TInterface "Gdk" "ModifierType"
    IO ()


accelLabelGetAccel ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    m (Word32,[Gdk.ModifierType])
accelLabelGetAccel _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    accelerator_key <- allocMem :: IO (Ptr Word32)
    accelerator_mods <- allocMem :: IO (Ptr CUInt)
    gtk_accel_label_get_accel _obj' accelerator_key accelerator_mods
    accelerator_key' <- peek accelerator_key
    accelerator_mods' <- peek accelerator_mods
    let accelerator_mods'' = wordToGFlags accelerator_mods'
    touchManagedPtr _obj
    freeMem accelerator_key
    freeMem accelerator_mods
    return (accelerator_key', accelerator_mods'')

-- method AccelLabel::get_accel_widget
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "Widget"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_get_accel_widget" gtk_accel_label_get_accel_widget :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    IO (Ptr Widget)


accelLabelGetAccelWidget ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    m Widget
accelLabelGetAccelWidget _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_accel_label_get_accel_widget _obj'
    checkUnexpectedReturnNULL "gtk_accel_label_get_accel_widget" result
    result' <- (newObject Widget) result
    touchManagedPtr _obj
    return result'

-- method AccelLabel::get_accel_width
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_get_accel_width" gtk_accel_label_get_accel_width :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    IO Word32


accelLabelGetAccelWidth ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    m Word32
accelLabelGetAccelWidth _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_accel_label_get_accel_width _obj'
    touchManagedPtr _obj
    return result

-- method AccelLabel::refetch
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_refetch" gtk_accel_label_refetch :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    IO CInt


accelLabelRefetch ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    m Bool
accelLabelRefetch _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_accel_label_refetch _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method AccelLabel::set_accel
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accelerator_key", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accelerator_mods", argType = TInterface "Gdk" "ModifierType", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accelerator_key", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accelerator_mods", argType = TInterface "Gdk" "ModifierType", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_set_accel" gtk_accel_label_set_accel :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    Word32 ->                               -- accelerator_key : TBasicType TUInt32
    CUInt ->                                -- accelerator_mods : TInterface "Gdk" "ModifierType"
    IO ()


accelLabelSetAccel ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- accelerator_key
    [Gdk.ModifierType] ->                   -- accelerator_mods
    m ()
accelLabelSetAccel _obj accelerator_key accelerator_mods = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let accelerator_mods' = gflagsToWord accelerator_mods
    gtk_accel_label_set_accel _obj' accelerator_key accelerator_mods'
    touchManagedPtr _obj
    return ()

-- method AccelLabel::set_accel_closure
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_closure", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_closure", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_set_accel_closure" gtk_accel_label_set_accel_closure :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    Ptr Closure ->                          -- accel_closure : TInterface "GObject" "Closure"
    IO ()


accelLabelSetAccelClosure ::
    (MonadIO m, AccelLabelK a) =>
    a ->                                    -- _obj
    Closure ->                              -- accel_closure
    m ()
accelLabelSetAccelClosure _obj accel_closure = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let accel_closure' = unsafeManagedPtrGetPtr accel_closure
    gtk_accel_label_set_accel_closure _obj' accel_closure'
    touchManagedPtr _obj
    touchManagedPtr accel_closure
    return ()

-- method AccelLabel::set_accel_widget
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "AccelLabel", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accel_label_set_accel_widget" gtk_accel_label_set_accel_widget :: 
    Ptr AccelLabel ->                       -- _obj : TInterface "Gtk" "AccelLabel"
    Ptr Widget ->                           -- accel_widget : TInterface "Gtk" "Widget"
    IO ()


accelLabelSetAccelWidget ::
    (MonadIO m, AccelLabelK a, WidgetK b) =>
    a ->                                    -- _obj
    b ->                                    -- accel_widget
    m ()
accelLabelSetAccelWidget _obj accel_widget = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let accel_widget' = unsafeManagedPtrCastPtr accel_widget
    gtk_accel_label_set_accel_widget _obj' accel_widget'
    touchManagedPtr _obj
    touchManagedPtr accel_widget
    return ()


