
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.Accessible
    ( 

-- * Exported types
    Accessible(..)                          ,
    AccessibleK                             ,
    toAccessible                            ,
    noAccessible                            ,


 -- * Methods
-- ** accessibleConnectWidgetDestroyed
    accessibleConnectWidgetDestroyed        ,


-- ** accessibleGetWidget
    accessibleGetWidget                     ,


-- ** accessibleSetWidget
    accessibleSetWidget                     ,




 -- * Properties
-- ** Widget
    AccessibleWidgetPropertyInfo            ,
    constructAccessibleWidget               ,
    getAccessibleWidget                     ,
    setAccessibleWidget                     ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype Accessible = Accessible (ForeignPtr Accessible)
foreign import ccall "gtk_accessible_get_type"
    c_gtk_accessible_get_type :: IO GType

type instance ParentTypes Accessible = AccessibleParentTypes
type AccessibleParentTypes = '[Atk.Object, GObject.Object]

instance GObject Accessible where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_gtk_accessible_get_type
    

class GObject o => AccessibleK o
instance (GObject o, IsDescendantOf Accessible o) => AccessibleK o

toAccessible :: AccessibleK o => o -> IO Accessible
toAccessible = unsafeCastTo Accessible

noAccessible :: Maybe Accessible
noAccessible = Nothing

-- VVV Prop "widget"
   -- Type: TInterface "Gtk" "Widget"
   -- Flags: [PropertyReadable,PropertyWritable]

getAccessibleWidget :: (MonadIO m, AccessibleK o) => o -> m Widget
getAccessibleWidget obj = liftIO $ getObjectPropertyObject obj "widget" Widget

setAccessibleWidget :: (MonadIO m, AccessibleK o, WidgetK a) => o -> a -> m ()
setAccessibleWidget obj val = liftIO $ setObjectPropertyObject obj "widget" val

constructAccessibleWidget :: (WidgetK a) => a -> IO ([Char], GValue)
constructAccessibleWidget val = constructObjectPropertyObject "widget" val

data AccessibleWidgetPropertyInfo
instance AttrInfo AccessibleWidgetPropertyInfo where
    type AttrAllowedOps AccessibleWidgetPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint AccessibleWidgetPropertyInfo = WidgetK
    type AttrBaseTypeConstraint AccessibleWidgetPropertyInfo = AccessibleK
    type AttrGetType AccessibleWidgetPropertyInfo = Widget
    type AttrLabel AccessibleWidgetPropertyInfo = "Accessible::widget"
    attrGet _ = getAccessibleWidget
    attrSet _ = setAccessibleWidget
    attrConstruct _ = constructAccessibleWidget

type instance AttributeList Accessible = AccessibleAttributeList
type AccessibleAttributeList = ('[ '("accessible-component-layer", Atk.ObjectAccessibleComponentLayerPropertyInfo), '("accessible-component-mdi-zorder", Atk.ObjectAccessibleComponentMdiZorderPropertyInfo), '("accessible-description", Atk.ObjectAccessibleDescriptionPropertyInfo), '("accessible-hypertext-nlinks", Atk.ObjectAccessibleHypertextNlinksPropertyInfo), '("accessible-name", Atk.ObjectAccessibleNamePropertyInfo), '("accessible-parent", Atk.ObjectAccessibleParentPropertyInfo), '("accessible-role", Atk.ObjectAccessibleRolePropertyInfo), '("accessible-table-caption", Atk.ObjectAccessibleTableCaptionPropertyInfo), '("accessible-table-caption-object", Atk.ObjectAccessibleTableCaptionObjectPropertyInfo), '("accessible-table-column-description", Atk.ObjectAccessibleTableColumnDescriptionPropertyInfo), '("accessible-table-column-header", Atk.ObjectAccessibleTableColumnHeaderPropertyInfo), '("accessible-table-row-description", Atk.ObjectAccessibleTableRowDescriptionPropertyInfo), '("accessible-table-row-header", Atk.ObjectAccessibleTableRowHeaderPropertyInfo), '("accessible-table-summary", Atk.ObjectAccessibleTableSummaryPropertyInfo), '("accessible-value", Atk.ObjectAccessibleValuePropertyInfo), '("widget", AccessibleWidgetPropertyInfo)] :: [(Symbol, *)])

type instance SignalList Accessible = AccessibleSignalList
type AccessibleSignalList = ('[ '("active-descendant-changed", Atk.ObjectActiveDescendantChangedSignalInfo), '("children-changed", Atk.ObjectChildrenChangedSignalInfo), '("focus-event", Atk.ObjectFocusEventSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("property-change", Atk.ObjectPropertyChangeSignalInfo), '("state-change", Atk.ObjectStateChangeSignalInfo), '("visible-data-changed", Atk.ObjectVisibleDataChangedSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method Accessible::connect_widget_destroyed
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accessible_connect_widget_destroyed" gtk_accessible_connect_widget_destroyed :: 
    Ptr Accessible ->                       -- _obj : TInterface "Gtk" "Accessible"
    IO ()

{-# DEPRECATED accessibleConnectWidgetDestroyed ["(Since version 3.4)","Use gtk_accessible_set_widget() and its vfuncs."]#-}
accessibleConnectWidgetDestroyed ::
    (MonadIO m, AccessibleK a) =>
    a ->                                    -- _obj
    m ()
accessibleConnectWidgetDestroyed _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_accessible_connect_widget_destroyed _obj'
    touchManagedPtr _obj
    return ()

-- method Accessible::get_widget
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "Widget"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accessible_get_widget" gtk_accessible_get_widget :: 
    Ptr Accessible ->                       -- _obj : TInterface "Gtk" "Accessible"
    IO (Ptr Widget)


accessibleGetWidget ::
    (MonadIO m, AccessibleK a) =>
    a ->                                    -- _obj
    m Widget
accessibleGetWidget _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_accessible_get_widget _obj'
    checkUnexpectedReturnNULL "gtk_accessible_get_widget" result
    result' <- (newObject Widget) result
    touchManagedPtr _obj
    return result'

-- method Accessible::set_widget
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Accessible", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accessible_set_widget" gtk_accessible_set_widget :: 
    Ptr Accessible ->                       -- _obj : TInterface "Gtk" "Accessible"
    Ptr Widget ->                           -- widget : TInterface "Gtk" "Widget"
    IO ()


accessibleSetWidget ::
    (MonadIO m, AccessibleK a, WidgetK b) =>
    a ->                                    -- _obj
    Maybe (b) ->                            -- widget
    m ()
accessibleSetWidget _obj widget = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    maybeWidget <- case widget of
        Nothing -> return nullPtr
        Just jWidget -> do
            let jWidget' = unsafeManagedPtrCastPtr jWidget
            return jWidget'
    gtk_accessible_set_widget _obj' maybeWidget
    touchManagedPtr _obj
    whenJust widget touchManagedPtr
    return ()


