
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.GestureZoom
    ( 

-- * Exported types
    GestureZoom(..)                         ,
    GestureZoomK                            ,
    toGestureZoom                           ,
    noGestureZoom                           ,


 -- * Methods
-- ** gestureZoomGetScaleDelta
    gestureZoomGetScaleDelta                ,


-- ** gestureZoomNew
    gestureZoomNew                          ,




 -- * Signals
-- ** ScaleChanged
    GestureZoomScaleChangedCallback         ,
    GestureZoomScaleChangedCallbackC        ,
    GestureZoomScaleChangedSignalInfo       ,
    afterGestureZoomScaleChanged            ,
    gestureZoomScaleChangedCallbackWrapper  ,
    gestureZoomScaleChangedClosure          ,
    mkGestureZoomScaleChangedCallback       ,
    noGestureZoomScaleChangedCallback       ,
    onGestureZoomScaleChanged               ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.GObject as GObject

newtype GestureZoom = GestureZoom (ForeignPtr GestureZoom)
foreign import ccall "gtk_gesture_zoom_get_type"
    c_gtk_gesture_zoom_get_type :: IO GType

type instance ParentTypes GestureZoom = GestureZoomParentTypes
type GestureZoomParentTypes = '[Gesture, EventController, GObject.Object]

instance GObject GestureZoom where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_gtk_gesture_zoom_get_type
    

class GObject o => GestureZoomK o
instance (GObject o, IsDescendantOf GestureZoom o) => GestureZoomK o

toGestureZoom :: GestureZoomK o => o -> IO GestureZoom
toGestureZoom = unsafeCastTo GestureZoom

noGestureZoom :: Maybe GestureZoom
noGestureZoom = Nothing

-- signal GestureZoom::scale-changed
type GestureZoomScaleChangedCallback =
    Double ->
    IO ()

noGestureZoomScaleChangedCallback :: Maybe GestureZoomScaleChangedCallback
noGestureZoomScaleChangedCallback = Nothing

type GestureZoomScaleChangedCallbackC =
    Ptr () ->                               -- object
    CDouble ->
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkGestureZoomScaleChangedCallback :: GestureZoomScaleChangedCallbackC -> IO (FunPtr GestureZoomScaleChangedCallbackC)

gestureZoomScaleChangedClosure :: GestureZoomScaleChangedCallback -> IO Closure
gestureZoomScaleChangedClosure cb = newCClosure =<< mkGestureZoomScaleChangedCallback wrapped
    where wrapped = gestureZoomScaleChangedCallbackWrapper cb

gestureZoomScaleChangedCallbackWrapper ::
    GestureZoomScaleChangedCallback ->
    Ptr () ->
    CDouble ->
    Ptr () ->
    IO ()
gestureZoomScaleChangedCallbackWrapper _cb _ scale _ = do
    let scale' = realToFrac scale
    _cb  scale'

onGestureZoomScaleChanged :: (GObject a, MonadIO m) => a -> GestureZoomScaleChangedCallback -> m SignalHandlerId
onGestureZoomScaleChanged obj cb = liftIO $ connectGestureZoomScaleChanged obj cb SignalConnectBefore
afterGestureZoomScaleChanged :: (GObject a, MonadIO m) => a -> GestureZoomScaleChangedCallback -> m SignalHandlerId
afterGestureZoomScaleChanged obj cb = connectGestureZoomScaleChanged obj cb SignalConnectAfter

connectGestureZoomScaleChanged :: (GObject a, MonadIO m) =>
                                  a -> GestureZoomScaleChangedCallback -> SignalConnectMode -> m SignalHandlerId
connectGestureZoomScaleChanged obj cb after = liftIO $ do
    cb' <- mkGestureZoomScaleChangedCallback (gestureZoomScaleChangedCallbackWrapper cb)
    connectSignalFunPtr obj "scale-changed" cb' after

type instance AttributeList GestureZoom = GestureZoomAttributeList
type GestureZoomAttributeList = ('[ '("n-points", GestureNPointsPropertyInfo), '("propagation-phase", EventControllerPropagationPhasePropertyInfo), '("widget", EventControllerWidgetPropertyInfo), '("window", GestureWindowPropertyInfo)] :: [(Symbol, *)])

data GestureZoomScaleChangedSignalInfo
instance SignalInfo GestureZoomScaleChangedSignalInfo where
    type HaskellCallbackType GestureZoomScaleChangedSignalInfo = GestureZoomScaleChangedCallback
    connectSignal _ = connectGestureZoomScaleChanged

type instance SignalList GestureZoom = GestureZoomSignalList
type GestureZoomSignalList = ('[ '("begin", GestureBeginSignalInfo), '("cancel", GestureCancelSignalInfo), '("end", GestureEndSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("scale-changed", GestureZoomScaleChangedSignalInfo), '("sequence-state-changed", GestureSequenceStateChangedSignalInfo), '("update", GestureUpdateSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method GestureZoom::new
-- method type : Constructor
-- Args : [Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "GestureZoom"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_gesture_zoom_new" gtk_gesture_zoom_new :: 
    Ptr Widget ->                           -- widget : TInterface "Gtk" "Widget"
    IO (Ptr GestureZoom)


gestureZoomNew ::
    (MonadIO m, WidgetK a) =>
    a ->                                    -- widget
    m GestureZoom
gestureZoomNew widget = liftIO $ do
    let widget' = unsafeManagedPtrCastPtr widget
    result <- gtk_gesture_zoom_new widget'
    checkUnexpectedReturnNULL "gtk_gesture_zoom_new" result
    result' <- (wrapObject GestureZoom) result
    touchManagedPtr widget
    return result'

-- method GestureZoom::get_scale_delta
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "GestureZoom", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "GestureZoom", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TDouble
-- throws : False
-- Skip return : False

foreign import ccall "gtk_gesture_zoom_get_scale_delta" gtk_gesture_zoom_get_scale_delta :: 
    Ptr GestureZoom ->                      -- _obj : TInterface "Gtk" "GestureZoom"
    IO CDouble


gestureZoomGetScaleDelta ::
    (MonadIO m, GestureZoomK a) =>
    a ->                                    -- _obj
    m Double
gestureZoomGetScaleDelta _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_gesture_zoom_get_scale_delta _obj'
    let result' = realToFrac result
    touchManagedPtr _obj
    return result'


