
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.ImageMenuItem
    ( 

-- * Exported types
    ImageMenuItem(..)                       ,
    ImageMenuItemK                          ,
    toImageMenuItem                         ,
    noImageMenuItem                         ,


 -- * Methods
-- ** imageMenuItemGetAlwaysShowImage
    imageMenuItemGetAlwaysShowImage         ,


-- ** imageMenuItemGetImage
    imageMenuItemGetImage                   ,


-- ** imageMenuItemGetUseStock
    imageMenuItemGetUseStock                ,


-- ** imageMenuItemNew
    imageMenuItemNew                        ,


-- ** imageMenuItemNewFromStock
    imageMenuItemNewFromStock               ,


-- ** imageMenuItemNewWithLabel
    imageMenuItemNewWithLabel               ,


-- ** imageMenuItemNewWithMnemonic
    imageMenuItemNewWithMnemonic            ,


-- ** imageMenuItemSetAccelGroup
    imageMenuItemSetAccelGroup              ,


-- ** imageMenuItemSetAlwaysShowImage
    imageMenuItemSetAlwaysShowImage         ,


-- ** imageMenuItemSetImage
    imageMenuItemSetImage                   ,


-- ** imageMenuItemSetUseStock
    imageMenuItemSetUseStock                ,




 -- * Properties
-- ** AccelGroup
    ImageMenuItemAccelGroupPropertyInfo     ,
    constructImageMenuItemAccelGroup        ,
    setImageMenuItemAccelGroup              ,


-- ** AlwaysShowImage
    ImageMenuItemAlwaysShowImagePropertyInfo,
    constructImageMenuItemAlwaysShowImage   ,
    getImageMenuItemAlwaysShowImage         ,
    setImageMenuItemAlwaysShowImage         ,


-- ** Image
    ImageMenuItemImagePropertyInfo          ,
    constructImageMenuItemImage             ,
    getImageMenuItemImage                   ,
    setImageMenuItemImage                   ,


-- ** UseStock
    ImageMenuItemUseStockPropertyInfo       ,
    constructImageMenuItemUseStock          ,
    getImageMenuItemUseStock                ,
    setImageMenuItemUseStock                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype ImageMenuItem = ImageMenuItem (ForeignPtr ImageMenuItem)
foreign import ccall "gtk_image_menu_item_get_type"
    c_gtk_image_menu_item_get_type :: IO GType

type instance ParentTypes ImageMenuItem = ImageMenuItemParentTypes
type ImageMenuItemParentTypes = '[MenuItem, Bin, Container, Widget, GObject.Object, Atk.ImplementorIface, Actionable, Activatable, Buildable]

instance GObject ImageMenuItem where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_image_menu_item_get_type
    

class GObject o => ImageMenuItemK o
instance (GObject o, IsDescendantOf ImageMenuItem o) => ImageMenuItemK o

toImageMenuItem :: ImageMenuItemK o => o -> IO ImageMenuItem
toImageMenuItem = unsafeCastTo ImageMenuItem

noImageMenuItem :: Maybe ImageMenuItem
noImageMenuItem = Nothing

-- VVV Prop "accel-group"
   -- Type: TInterface "Gtk" "AccelGroup"
   -- Flags: [PropertyWritable]

setImageMenuItemAccelGroup :: (MonadIO m, ImageMenuItemK o, AccelGroupK a) => o -> a -> m ()
setImageMenuItemAccelGroup obj val = liftIO $ setObjectPropertyObject obj "accel-group" val

constructImageMenuItemAccelGroup :: (AccelGroupK a) => a -> IO ([Char], GValue)
constructImageMenuItemAccelGroup val = constructObjectPropertyObject "accel-group" val

data ImageMenuItemAccelGroupPropertyInfo
instance AttrInfo ImageMenuItemAccelGroupPropertyInfo where
    type AttrAllowedOps ImageMenuItemAccelGroupPropertyInfo = '[ 'AttrSet, 'AttrConstruct]
    type AttrSetTypeConstraint ImageMenuItemAccelGroupPropertyInfo = AccelGroupK
    type AttrBaseTypeConstraint ImageMenuItemAccelGroupPropertyInfo = ImageMenuItemK
    type AttrGetType ImageMenuItemAccelGroupPropertyInfo = ()
    type AttrLabel ImageMenuItemAccelGroupPropertyInfo = "ImageMenuItem::accel-group"
    attrGet _ = undefined
    attrSet _ = setImageMenuItemAccelGroup
    attrConstruct _ = constructImageMenuItemAccelGroup

-- VVV Prop "always-show-image"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstruct]

getImageMenuItemAlwaysShowImage :: (MonadIO m, ImageMenuItemK o) => o -> m Bool
getImageMenuItemAlwaysShowImage obj = liftIO $ getObjectPropertyBool obj "always-show-image"

setImageMenuItemAlwaysShowImage :: (MonadIO m, ImageMenuItemK o) => o -> Bool -> m ()
setImageMenuItemAlwaysShowImage obj val = liftIO $ setObjectPropertyBool obj "always-show-image" val

constructImageMenuItemAlwaysShowImage :: Bool -> IO ([Char], GValue)
constructImageMenuItemAlwaysShowImage val = constructObjectPropertyBool "always-show-image" val

data ImageMenuItemAlwaysShowImagePropertyInfo
instance AttrInfo ImageMenuItemAlwaysShowImagePropertyInfo where
    type AttrAllowedOps ImageMenuItemAlwaysShowImagePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint ImageMenuItemAlwaysShowImagePropertyInfo = (~) Bool
    type AttrBaseTypeConstraint ImageMenuItemAlwaysShowImagePropertyInfo = ImageMenuItemK
    type AttrGetType ImageMenuItemAlwaysShowImagePropertyInfo = Bool
    type AttrLabel ImageMenuItemAlwaysShowImagePropertyInfo = "ImageMenuItem::always-show-image"
    attrGet _ = getImageMenuItemAlwaysShowImage
    attrSet _ = setImageMenuItemAlwaysShowImage
    attrConstruct _ = constructImageMenuItemAlwaysShowImage

-- VVV Prop "image"
   -- Type: TInterface "Gtk" "Widget"
   -- Flags: [PropertyReadable,PropertyWritable]

getImageMenuItemImage :: (MonadIO m, ImageMenuItemK o) => o -> m Widget
getImageMenuItemImage obj = liftIO $ getObjectPropertyObject obj "image" Widget

setImageMenuItemImage :: (MonadIO m, ImageMenuItemK o, WidgetK a) => o -> a -> m ()
setImageMenuItemImage obj val = liftIO $ setObjectPropertyObject obj "image" val

constructImageMenuItemImage :: (WidgetK a) => a -> IO ([Char], GValue)
constructImageMenuItemImage val = constructObjectPropertyObject "image" val

data ImageMenuItemImagePropertyInfo
instance AttrInfo ImageMenuItemImagePropertyInfo where
    type AttrAllowedOps ImageMenuItemImagePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint ImageMenuItemImagePropertyInfo = WidgetK
    type AttrBaseTypeConstraint ImageMenuItemImagePropertyInfo = ImageMenuItemK
    type AttrGetType ImageMenuItemImagePropertyInfo = Widget
    type AttrLabel ImageMenuItemImagePropertyInfo = "ImageMenuItem::image"
    attrGet _ = getImageMenuItemImage
    attrSet _ = setImageMenuItemImage
    attrConstruct _ = constructImageMenuItemImage

-- VVV Prop "use-stock"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstruct]

getImageMenuItemUseStock :: (MonadIO m, ImageMenuItemK o) => o -> m Bool
getImageMenuItemUseStock obj = liftIO $ getObjectPropertyBool obj "use-stock"

setImageMenuItemUseStock :: (MonadIO m, ImageMenuItemK o) => o -> Bool -> m ()
setImageMenuItemUseStock obj val = liftIO $ setObjectPropertyBool obj "use-stock" val

constructImageMenuItemUseStock :: Bool -> IO ([Char], GValue)
constructImageMenuItemUseStock val = constructObjectPropertyBool "use-stock" val

data ImageMenuItemUseStockPropertyInfo
instance AttrInfo ImageMenuItemUseStockPropertyInfo where
    type AttrAllowedOps ImageMenuItemUseStockPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint ImageMenuItemUseStockPropertyInfo = (~) Bool
    type AttrBaseTypeConstraint ImageMenuItemUseStockPropertyInfo = ImageMenuItemK
    type AttrGetType ImageMenuItemUseStockPropertyInfo = Bool
    type AttrLabel ImageMenuItemUseStockPropertyInfo = "ImageMenuItem::use-stock"
    attrGet _ = getImageMenuItemUseStock
    attrSet _ = setImageMenuItemUseStock
    attrConstruct _ = constructImageMenuItemUseStock

type instance AttributeList ImageMenuItem = ImageMenuItemAttributeList
type ImageMenuItemAttributeList = ('[ '("accel-group", ImageMenuItemAccelGroupPropertyInfo), '("accel-path", MenuItemAccelPathPropertyInfo), '("action-name", ActionableActionNamePropertyInfo), '("action-target", ActionableActionTargetPropertyInfo), '("always-show-image", ImageMenuItemAlwaysShowImagePropertyInfo), '("app-paintable", WidgetAppPaintablePropertyInfo), '("border-width", ContainerBorderWidthPropertyInfo), '("can-default", WidgetCanDefaultPropertyInfo), '("can-focus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("composite-child", WidgetCompositeChildPropertyInfo), '("double-buffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("has-default", WidgetHasDefaultPropertyInfo), '("has-focus", WidgetHasFocusPropertyInfo), '("has-tooltip", WidgetHasTooltipPropertyInfo), '("height-request", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpand-set", WidgetHexpandSetPropertyInfo), '("image", ImageMenuItemImagePropertyInfo), '("is-focus", WidgetIsFocusPropertyInfo), '("label", MenuItemLabelPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("margin-bottom", WidgetMarginBottomPropertyInfo), '("margin-end", WidgetMarginEndPropertyInfo), '("margin-left", WidgetMarginLeftPropertyInfo), '("margin-right", WidgetMarginRightPropertyInfo), '("margin-start", WidgetMarginStartPropertyInfo), '("margin-top", WidgetMarginTopPropertyInfo), '("name", WidgetNamePropertyInfo), '("no-show-all", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receives-default", WidgetReceivesDefaultPropertyInfo), '("related-action", ActivatableRelatedActionPropertyInfo), '("resize-mode", ContainerResizeModePropertyInfo), '("right-justified", MenuItemRightJustifiedPropertyInfo), '("scale-factor", WidgetScaleFactorPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("style", WidgetStylePropertyInfo), '("submenu", MenuItemSubmenuPropertyInfo), '("tooltip-markup", WidgetTooltipMarkupPropertyInfo), '("tooltip-text", WidgetTooltipTextPropertyInfo), '("use-action-appearance", ActivatableUseActionAppearancePropertyInfo), '("use-stock", ImageMenuItemUseStockPropertyInfo), '("use-underline", MenuItemUseUnderlinePropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpand-set", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("width-request", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo)] :: [(Symbol, *)])

type instance SignalList ImageMenuItem = ImageMenuItemSignalList
type ImageMenuItemSignalList = ('[ '("accel-closures-changed", WidgetAccelClosuresChangedSignalInfo), '("activate", MenuItemActivateSignalInfo), '("activate-item", MenuItemActivateItemSignalInfo), '("add", ContainerAddSignalInfo), '("button-press-event", WidgetButtonPressEventSignalInfo), '("button-release-event", WidgetButtonReleaseEventSignalInfo), '("can-activate-accel", WidgetCanActivateAccelSignalInfo), '("check-resize", ContainerCheckResizeSignalInfo), '("child-notify", WidgetChildNotifySignalInfo), '("composited-changed", WidgetCompositedChangedSignalInfo), '("configure-event", WidgetConfigureEventSignalInfo), '("damage-event", WidgetDamageEventSignalInfo), '("delete-event", WidgetDeleteEventSignalInfo), '("deselect", MenuItemDeselectSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroy-event", WidgetDestroyEventSignalInfo), '("direction-changed", WidgetDirectionChangedSignalInfo), '("drag-begin", WidgetDragBeginSignalInfo), '("drag-data-delete", WidgetDragDataDeleteSignalInfo), '("drag-data-get", WidgetDragDataGetSignalInfo), '("drag-data-received", WidgetDragDataReceivedSignalInfo), '("drag-drop", WidgetDragDropSignalInfo), '("drag-end", WidgetDragEndSignalInfo), '("drag-failed", WidgetDragFailedSignalInfo), '("drag-leave", WidgetDragLeaveSignalInfo), '("drag-motion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enter-notify-event", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("event-after", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focus-in-event", WidgetFocusInEventSignalInfo), '("focus-out-event", WidgetFocusOutEventSignalInfo), '("grab-broken-event", WidgetGrabBrokenEventSignalInfo), '("grab-focus", WidgetGrabFocusSignalInfo), '("grab-notify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchy-changed", WidgetHierarchyChangedSignalInfo), '("key-press-event", WidgetKeyPressEventSignalInfo), '("key-release-event", WidgetKeyReleaseEventSignalInfo), '("keynav-failed", WidgetKeynavFailedSignalInfo), '("leave-notify-event", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("map-event", WidgetMapEventSignalInfo), '("mnemonic-activate", WidgetMnemonicActivateSignalInfo), '("motion-notify-event", WidgetMotionNotifyEventSignalInfo), '("move-focus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parent-set", WidgetParentSetSignalInfo), '("popup-menu", WidgetPopupMenuSignalInfo), '("property-notify-event", WidgetPropertyNotifyEventSignalInfo), '("proximity-in-event", WidgetProximityInEventSignalInfo), '("proximity-out-event", WidgetProximityOutEventSignalInfo), '("query-tooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screen-changed", WidgetScreenChangedSignalInfo), '("scroll-event", WidgetScrollEventSignalInfo), '("select", MenuItemSelectSignalInfo), '("selection-clear-event", WidgetSelectionClearEventSignalInfo), '("selection-get", WidgetSelectionGetSignalInfo), '("selection-notify-event", WidgetSelectionNotifyEventSignalInfo), '("selection-received", WidgetSelectionReceivedSignalInfo), '("selection-request-event", WidgetSelectionRequestEventSignalInfo), '("set-focus-child", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("show-help", WidgetShowHelpSignalInfo), '("size-allocate", WidgetSizeAllocateSignalInfo), '("state-changed", WidgetStateChangedSignalInfo), '("state-flags-changed", WidgetStateFlagsChangedSignalInfo), '("style-set", WidgetStyleSetSignalInfo), '("style-updated", WidgetStyleUpdatedSignalInfo), '("toggle-size-allocate", MenuItemToggleSizeAllocateSignalInfo), '("toggle-size-request", MenuItemToggleSizeRequestSignalInfo), '("touch-event", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmap-event", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibility-notify-event", WidgetVisibilityNotifyEventSignalInfo), '("window-state-event", WidgetWindowStateEventSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method ImageMenuItem::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- hInArgs : []
-- returnType : TInterface "Gtk" "ImageMenuItem"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_new" gtk_image_menu_item_new :: 
    IO (Ptr ImageMenuItem)

{-# DEPRECATED imageMenuItemNew ["(Since version 3.10)","Use gtk_menu_item_new() instead."]#-}
imageMenuItemNew ::
    (MonadIO m) =>
    m ImageMenuItem
imageMenuItemNew  = liftIO $ do
    result <- gtk_image_menu_item_new
    checkUnexpectedReturnNULL "gtk_image_menu_item_new" result
    result' <- (newObject ImageMenuItem) result
    return result'

-- method ImageMenuItem::new_from_stock
-- method type : Constructor
-- Args : [Arg {argName = "stock_id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_group", argType = TInterface "Gtk" "AccelGroup", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "stock_id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_group", argType = TInterface "Gtk" "AccelGroup", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "ImageMenuItem"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_new_from_stock" gtk_image_menu_item_new_from_stock :: 
    CString ->                              -- stock_id : TBasicType TUTF8
    Ptr AccelGroup ->                       -- accel_group : TInterface "Gtk" "AccelGroup"
    IO (Ptr ImageMenuItem)

{-# DEPRECATED imageMenuItemNewFromStock ["(Since version 3.10)","Use gtk_menu_item_new_with_mnemonic() instead."]#-}
imageMenuItemNewFromStock ::
    (MonadIO m, AccelGroupK a) =>
    T.Text ->                               -- stock_id
    Maybe (a) ->                            -- accel_group
    m ImageMenuItem
imageMenuItemNewFromStock stock_id accel_group = liftIO $ do
    stock_id' <- textToCString stock_id
    maybeAccel_group <- case accel_group of
        Nothing -> return nullPtr
        Just jAccel_group -> do
            let jAccel_group' = unsafeManagedPtrCastPtr jAccel_group
            return jAccel_group'
    result <- gtk_image_menu_item_new_from_stock stock_id' maybeAccel_group
    checkUnexpectedReturnNULL "gtk_image_menu_item_new_from_stock" result
    result' <- (newObject ImageMenuItem) result
    whenJust accel_group touchManagedPtr
    freeMem stock_id'
    return result'

-- method ImageMenuItem::new_with_label
-- method type : Constructor
-- Args : [Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "ImageMenuItem"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_new_with_label" gtk_image_menu_item_new_with_label :: 
    CString ->                              -- label : TBasicType TUTF8
    IO (Ptr ImageMenuItem)

{-# DEPRECATED imageMenuItemNewWithLabel ["(Since version 3.10)","Use gtk_menu_item_new_with_label() instead."]#-}
imageMenuItemNewWithLabel ::
    (MonadIO m) =>
    T.Text ->                               -- label
    m ImageMenuItem
imageMenuItemNewWithLabel label = liftIO $ do
    label' <- textToCString label
    result <- gtk_image_menu_item_new_with_label label'
    checkUnexpectedReturnNULL "gtk_image_menu_item_new_with_label" result
    result' <- (newObject ImageMenuItem) result
    freeMem label'
    return result'

-- method ImageMenuItem::new_with_mnemonic
-- method type : Constructor
-- Args : [Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "ImageMenuItem"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_new_with_mnemonic" gtk_image_menu_item_new_with_mnemonic :: 
    CString ->                              -- label : TBasicType TUTF8
    IO (Ptr ImageMenuItem)

{-# DEPRECATED imageMenuItemNewWithMnemonic ["(Since version 3.10)","Use gtk_menu_item_new_with_mnemonic() instead."]#-}
imageMenuItemNewWithMnemonic ::
    (MonadIO m) =>
    T.Text ->                               -- label
    m ImageMenuItem
imageMenuItemNewWithMnemonic label = liftIO $ do
    label' <- textToCString label
    result <- gtk_image_menu_item_new_with_mnemonic label'
    checkUnexpectedReturnNULL "gtk_image_menu_item_new_with_mnemonic" result
    result' <- (newObject ImageMenuItem) result
    freeMem label'
    return result'

-- method ImageMenuItem::get_always_show_image
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_get_always_show_image" gtk_image_menu_item_get_always_show_image :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    IO CInt

{-# DEPRECATED imageMenuItemGetAlwaysShowImage ["(Since version 3.10)"]#-}
imageMenuItemGetAlwaysShowImage ::
    (MonadIO m, ImageMenuItemK a) =>
    a ->                                    -- _obj
    m Bool
imageMenuItemGetAlwaysShowImage _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_image_menu_item_get_always_show_image _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method ImageMenuItem::get_image
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "Widget"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_get_image" gtk_image_menu_item_get_image :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    IO (Ptr Widget)

{-# DEPRECATED imageMenuItemGetImage ["(Since version 3.10)"]#-}
imageMenuItemGetImage ::
    (MonadIO m, ImageMenuItemK a) =>
    a ->                                    -- _obj
    m Widget
imageMenuItemGetImage _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_image_menu_item_get_image _obj'
    checkUnexpectedReturnNULL "gtk_image_menu_item_get_image" result
    result' <- (newObject Widget) result
    touchManagedPtr _obj
    return result'

-- method ImageMenuItem::get_use_stock
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_get_use_stock" gtk_image_menu_item_get_use_stock :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    IO CInt

{-# DEPRECATED imageMenuItemGetUseStock ["(Since version 3.10)"]#-}
imageMenuItemGetUseStock ::
    (MonadIO m, ImageMenuItemK a) =>
    a ->                                    -- _obj
    m Bool
imageMenuItemGetUseStock _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_image_menu_item_get_use_stock _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method ImageMenuItem::set_accel_group
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_group", argType = TInterface "Gtk" "AccelGroup", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "accel_group", argType = TInterface "Gtk" "AccelGroup", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_set_accel_group" gtk_image_menu_item_set_accel_group :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    Ptr AccelGroup ->                       -- accel_group : TInterface "Gtk" "AccelGroup"
    IO ()

{-# DEPRECATED imageMenuItemSetAccelGroup ["(Since version 3.10)"]#-}
imageMenuItemSetAccelGroup ::
    (MonadIO m, ImageMenuItemK a, AccelGroupK b) =>
    a ->                                    -- _obj
    b ->                                    -- accel_group
    m ()
imageMenuItemSetAccelGroup _obj accel_group = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let accel_group' = unsafeManagedPtrCastPtr accel_group
    gtk_image_menu_item_set_accel_group _obj' accel_group'
    touchManagedPtr _obj
    touchManagedPtr accel_group
    return ()

-- method ImageMenuItem::set_always_show_image
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "always_show", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "always_show", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_set_always_show_image" gtk_image_menu_item_set_always_show_image :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    CInt ->                                 -- always_show : TBasicType TBoolean
    IO ()

{-# DEPRECATED imageMenuItemSetAlwaysShowImage ["(Since version 3.10)"]#-}
imageMenuItemSetAlwaysShowImage ::
    (MonadIO m, ImageMenuItemK a) =>
    a ->                                    -- _obj
    Bool ->                                 -- always_show
    m ()
imageMenuItemSetAlwaysShowImage _obj always_show = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let always_show' = (fromIntegral . fromEnum) always_show
    gtk_image_menu_item_set_always_show_image _obj' always_show'
    touchManagedPtr _obj
    return ()

-- method ImageMenuItem::set_image
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "image", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "image", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_set_image" gtk_image_menu_item_set_image :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    Ptr Widget ->                           -- image : TInterface "Gtk" "Widget"
    IO ()

{-# DEPRECATED imageMenuItemSetImage ["(Since version 3.10)"]#-}
imageMenuItemSetImage ::
    (MonadIO m, ImageMenuItemK a, WidgetK b) =>
    a ->                                    -- _obj
    Maybe (b) ->                            -- image
    m ()
imageMenuItemSetImage _obj image = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    maybeImage <- case image of
        Nothing -> return nullPtr
        Just jImage -> do
            let jImage' = unsafeManagedPtrCastPtr jImage
            return jImage'
    gtk_image_menu_item_set_image _obj' maybeImage
    touchManagedPtr _obj
    whenJust image touchManagedPtr
    return ()

-- method ImageMenuItem::set_use_stock
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_stock", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "ImageMenuItem", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_stock", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_image_menu_item_set_use_stock" gtk_image_menu_item_set_use_stock :: 
    Ptr ImageMenuItem ->                    -- _obj : TInterface "Gtk" "ImageMenuItem"
    CInt ->                                 -- use_stock : TBasicType TBoolean
    IO ()

{-# DEPRECATED imageMenuItemSetUseStock ["(Since version 3.10)"]#-}
imageMenuItemSetUseStock ::
    (MonadIO m, ImageMenuItemK a) =>
    a ->                                    -- _obj
    Bool ->                                 -- use_stock
    m ()
imageMenuItemSetUseStock _obj use_stock = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let use_stock' = (fromIntegral . fromEnum) use_stock
    gtk_image_menu_item_set_use_stock _obj' use_stock'
    touchManagedPtr _obj
    return ()


