
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.MenuToolButton
    ( 

-- * Exported types
    MenuToolButton(..)                      ,
    MenuToolButtonK                         ,
    toMenuToolButton                        ,
    noMenuToolButton                        ,


 -- * Methods
-- ** menuToolButtonGetMenu
    menuToolButtonGetMenu                   ,


-- ** menuToolButtonNew
    menuToolButtonNew                       ,


-- ** menuToolButtonNewFromStock
    menuToolButtonNewFromStock              ,


-- ** menuToolButtonSetArrowTooltipMarkup
    menuToolButtonSetArrowTooltipMarkup     ,


-- ** menuToolButtonSetArrowTooltipText
    menuToolButtonSetArrowTooltipText       ,


-- ** menuToolButtonSetMenu
    menuToolButtonSetMenu                   ,




 -- * Properties
-- ** Menu
    MenuToolButtonMenuPropertyInfo          ,
    constructMenuToolButtonMenu             ,
    getMenuToolButtonMenu                   ,
    setMenuToolButtonMenu                   ,




 -- * Signals
-- ** ShowMenu
    MenuToolButtonShowMenuCallback          ,
    MenuToolButtonShowMenuCallbackC         ,
    MenuToolButtonShowMenuSignalInfo        ,
    afterMenuToolButtonShowMenu             ,
    menuToolButtonShowMenuCallbackWrapper   ,
    menuToolButtonShowMenuClosure           ,
    mkMenuToolButtonShowMenuCallback        ,
    noMenuToolButtonShowMenuCallback        ,
    onMenuToolButtonShowMenu                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype MenuToolButton = MenuToolButton (ForeignPtr MenuToolButton)
foreign import ccall "gtk_menu_tool_button_get_type"
    c_gtk_menu_tool_button_get_type :: IO GType

type instance ParentTypes MenuToolButton = MenuToolButtonParentTypes
type MenuToolButtonParentTypes = '[ToolButton, ToolItem, Bin, Container, Widget, GObject.Object, Atk.ImplementorIface, Actionable, Activatable, Buildable]

instance GObject MenuToolButton where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_menu_tool_button_get_type
    

class GObject o => MenuToolButtonK o
instance (GObject o, IsDescendantOf MenuToolButton o) => MenuToolButtonK o

toMenuToolButton :: MenuToolButtonK o => o -> IO MenuToolButton
toMenuToolButton = unsafeCastTo MenuToolButton

noMenuToolButton :: Maybe MenuToolButton
noMenuToolButton = Nothing

-- signal MenuToolButton::show-menu
type MenuToolButtonShowMenuCallback =
    IO ()

noMenuToolButtonShowMenuCallback :: Maybe MenuToolButtonShowMenuCallback
noMenuToolButtonShowMenuCallback = Nothing

type MenuToolButtonShowMenuCallbackC =
    Ptr () ->                               -- object
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkMenuToolButtonShowMenuCallback :: MenuToolButtonShowMenuCallbackC -> IO (FunPtr MenuToolButtonShowMenuCallbackC)

menuToolButtonShowMenuClosure :: MenuToolButtonShowMenuCallback -> IO Closure
menuToolButtonShowMenuClosure cb = newCClosure =<< mkMenuToolButtonShowMenuCallback wrapped
    where wrapped = menuToolButtonShowMenuCallbackWrapper cb

menuToolButtonShowMenuCallbackWrapper ::
    MenuToolButtonShowMenuCallback ->
    Ptr () ->
    Ptr () ->
    IO ()
menuToolButtonShowMenuCallbackWrapper _cb _ _ = do
    _cb 

onMenuToolButtonShowMenu :: (GObject a, MonadIO m) => a -> MenuToolButtonShowMenuCallback -> m SignalHandlerId
onMenuToolButtonShowMenu obj cb = liftIO $ connectMenuToolButtonShowMenu obj cb SignalConnectBefore
afterMenuToolButtonShowMenu :: (GObject a, MonadIO m) => a -> MenuToolButtonShowMenuCallback -> m SignalHandlerId
afterMenuToolButtonShowMenu obj cb = connectMenuToolButtonShowMenu obj cb SignalConnectAfter

connectMenuToolButtonShowMenu :: (GObject a, MonadIO m) =>
                                 a -> MenuToolButtonShowMenuCallback -> SignalConnectMode -> m SignalHandlerId
connectMenuToolButtonShowMenu obj cb after = liftIO $ do
    cb' <- mkMenuToolButtonShowMenuCallback (menuToolButtonShowMenuCallbackWrapper cb)
    connectSignalFunPtr obj "show-menu" cb' after

-- VVV Prop "menu"
   -- Type: TInterface "Gtk" "Menu"
   -- Flags: [PropertyReadable,PropertyWritable]

getMenuToolButtonMenu :: (MonadIO m, MenuToolButtonK o) => o -> m Menu
getMenuToolButtonMenu obj = liftIO $ getObjectPropertyObject obj "menu" Menu

setMenuToolButtonMenu :: (MonadIO m, MenuToolButtonK o, MenuK a) => o -> a -> m ()
setMenuToolButtonMenu obj val = liftIO $ setObjectPropertyObject obj "menu" val

constructMenuToolButtonMenu :: (MenuK a) => a -> IO ([Char], GValue)
constructMenuToolButtonMenu val = constructObjectPropertyObject "menu" val

data MenuToolButtonMenuPropertyInfo
instance AttrInfo MenuToolButtonMenuPropertyInfo where
    type AttrAllowedOps MenuToolButtonMenuPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint MenuToolButtonMenuPropertyInfo = MenuK
    type AttrBaseTypeConstraint MenuToolButtonMenuPropertyInfo = MenuToolButtonK
    type AttrGetType MenuToolButtonMenuPropertyInfo = Menu
    type AttrLabel MenuToolButtonMenuPropertyInfo = "MenuToolButton::menu"
    attrGet _ = getMenuToolButtonMenu
    attrSet _ = setMenuToolButtonMenu
    attrConstruct _ = constructMenuToolButtonMenu

type instance AttributeList MenuToolButton = MenuToolButtonAttributeList
type MenuToolButtonAttributeList = ('[ '("action-name", ActionableActionNamePropertyInfo), '("action-target", ActionableActionTargetPropertyInfo), '("app-paintable", WidgetAppPaintablePropertyInfo), '("border-width", ContainerBorderWidthPropertyInfo), '("can-default", WidgetCanDefaultPropertyInfo), '("can-focus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("composite-child", WidgetCompositeChildPropertyInfo), '("double-buffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("has-default", WidgetHasDefaultPropertyInfo), '("has-focus", WidgetHasFocusPropertyInfo), '("has-tooltip", WidgetHasTooltipPropertyInfo), '("height-request", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpand-set", WidgetHexpandSetPropertyInfo), '("icon-name", ToolButtonIconNamePropertyInfo), '("icon-widget", ToolButtonIconWidgetPropertyInfo), '("is-focus", WidgetIsFocusPropertyInfo), '("is-important", ToolItemIsImportantPropertyInfo), '("label", ToolButtonLabelPropertyInfo), '("label-widget", ToolButtonLabelWidgetPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("margin-bottom", WidgetMarginBottomPropertyInfo), '("margin-end", WidgetMarginEndPropertyInfo), '("margin-left", WidgetMarginLeftPropertyInfo), '("margin-right", WidgetMarginRightPropertyInfo), '("margin-start", WidgetMarginStartPropertyInfo), '("margin-top", WidgetMarginTopPropertyInfo), '("menu", MenuToolButtonMenuPropertyInfo), '("name", WidgetNamePropertyInfo), '("no-show-all", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receives-default", WidgetReceivesDefaultPropertyInfo), '("related-action", ActivatableRelatedActionPropertyInfo), '("resize-mode", ContainerResizeModePropertyInfo), '("scale-factor", WidgetScaleFactorPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("stock-id", ToolButtonStockIdPropertyInfo), '("style", WidgetStylePropertyInfo), '("tooltip-markup", WidgetTooltipMarkupPropertyInfo), '("tooltip-text", WidgetTooltipTextPropertyInfo), '("use-action-appearance", ActivatableUseActionAppearancePropertyInfo), '("use-underline", ToolButtonUseUnderlinePropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpand-set", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("visible-horizontal", ToolItemVisibleHorizontalPropertyInfo), '("visible-vertical", ToolItemVisibleVerticalPropertyInfo), '("width-request", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo)] :: [(Symbol, *)])

data MenuToolButtonShowMenuSignalInfo
instance SignalInfo MenuToolButtonShowMenuSignalInfo where
    type HaskellCallbackType MenuToolButtonShowMenuSignalInfo = MenuToolButtonShowMenuCallback
    connectSignal _ = connectMenuToolButtonShowMenu

type instance SignalList MenuToolButton = MenuToolButtonSignalList
type MenuToolButtonSignalList = ('[ '("accel-closures-changed", WidgetAccelClosuresChangedSignalInfo), '("add", ContainerAddSignalInfo), '("button-press-event", WidgetButtonPressEventSignalInfo), '("button-release-event", WidgetButtonReleaseEventSignalInfo), '("can-activate-accel", WidgetCanActivateAccelSignalInfo), '("check-resize", ContainerCheckResizeSignalInfo), '("child-notify", WidgetChildNotifySignalInfo), '("clicked", ToolButtonClickedSignalInfo), '("composited-changed", WidgetCompositedChangedSignalInfo), '("configure-event", WidgetConfigureEventSignalInfo), '("create-menu-proxy", ToolItemCreateMenuProxySignalInfo), '("damage-event", WidgetDamageEventSignalInfo), '("delete-event", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroy-event", WidgetDestroyEventSignalInfo), '("direction-changed", WidgetDirectionChangedSignalInfo), '("drag-begin", WidgetDragBeginSignalInfo), '("drag-data-delete", WidgetDragDataDeleteSignalInfo), '("drag-data-get", WidgetDragDataGetSignalInfo), '("drag-data-received", WidgetDragDataReceivedSignalInfo), '("drag-drop", WidgetDragDropSignalInfo), '("drag-end", WidgetDragEndSignalInfo), '("drag-failed", WidgetDragFailedSignalInfo), '("drag-leave", WidgetDragLeaveSignalInfo), '("drag-motion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enter-notify-event", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("event-after", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focus-in-event", WidgetFocusInEventSignalInfo), '("focus-out-event", WidgetFocusOutEventSignalInfo), '("grab-broken-event", WidgetGrabBrokenEventSignalInfo), '("grab-focus", WidgetGrabFocusSignalInfo), '("grab-notify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchy-changed", WidgetHierarchyChangedSignalInfo), '("key-press-event", WidgetKeyPressEventSignalInfo), '("key-release-event", WidgetKeyReleaseEventSignalInfo), '("keynav-failed", WidgetKeynavFailedSignalInfo), '("leave-notify-event", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("map-event", WidgetMapEventSignalInfo), '("mnemonic-activate", WidgetMnemonicActivateSignalInfo), '("motion-notify-event", WidgetMotionNotifyEventSignalInfo), '("move-focus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parent-set", WidgetParentSetSignalInfo), '("popup-menu", WidgetPopupMenuSignalInfo), '("property-notify-event", WidgetPropertyNotifyEventSignalInfo), '("proximity-in-event", WidgetProximityInEventSignalInfo), '("proximity-out-event", WidgetProximityOutEventSignalInfo), '("query-tooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screen-changed", WidgetScreenChangedSignalInfo), '("scroll-event", WidgetScrollEventSignalInfo), '("selection-clear-event", WidgetSelectionClearEventSignalInfo), '("selection-get", WidgetSelectionGetSignalInfo), '("selection-notify-event", WidgetSelectionNotifyEventSignalInfo), '("selection-received", WidgetSelectionReceivedSignalInfo), '("selection-request-event", WidgetSelectionRequestEventSignalInfo), '("set-focus-child", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("show-help", WidgetShowHelpSignalInfo), '("show-menu", MenuToolButtonShowMenuSignalInfo), '("size-allocate", WidgetSizeAllocateSignalInfo), '("state-changed", WidgetStateChangedSignalInfo), '("state-flags-changed", WidgetStateFlagsChangedSignalInfo), '("style-set", WidgetStyleSetSignalInfo), '("style-updated", WidgetStyleUpdatedSignalInfo), '("toolbar-reconfigured", ToolItemToolbarReconfiguredSignalInfo), '("touch-event", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmap-event", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibility-notify-event", WidgetVisibilityNotifyEventSignalInfo), '("window-state-event", WidgetWindowStateEventSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method MenuToolButton::new
-- method type : Constructor
-- Args : [Arg {argName = "icon_widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "icon_widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "label", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = True, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "MenuToolButton"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_new" gtk_menu_tool_button_new :: 
    Ptr Widget ->                           -- icon_widget : TInterface "Gtk" "Widget"
    CString ->                              -- label : TBasicType TUTF8
    IO (Ptr MenuToolButton)


menuToolButtonNew ::
    (MonadIO m, WidgetK a) =>
    Maybe (a) ->                            -- icon_widget
    Maybe (T.Text) ->                       -- label
    m MenuToolButton
menuToolButtonNew icon_widget label = liftIO $ do
    maybeIcon_widget <- case icon_widget of
        Nothing -> return nullPtr
        Just jIcon_widget -> do
            let jIcon_widget' = unsafeManagedPtrCastPtr jIcon_widget
            return jIcon_widget'
    maybeLabel <- case label of
        Nothing -> return nullPtr
        Just jLabel -> do
            jLabel' <- textToCString jLabel
            return jLabel'
    result <- gtk_menu_tool_button_new maybeIcon_widget maybeLabel
    checkUnexpectedReturnNULL "gtk_menu_tool_button_new" result
    result' <- (newObject MenuToolButton) result
    whenJust icon_widget touchManagedPtr
    freeMem maybeLabel
    return result'

-- method MenuToolButton::new_from_stock
-- method type : Constructor
-- Args : [Arg {argName = "stock_id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "stock_id", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "MenuToolButton"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_new_from_stock" gtk_menu_tool_button_new_from_stock :: 
    CString ->                              -- stock_id : TBasicType TUTF8
    IO (Ptr MenuToolButton)

{-# DEPRECATED menuToolButtonNewFromStock ["(Since version 3.10)","Use gtk_menu_tool_button_new() instead."]#-}
menuToolButtonNewFromStock ::
    (MonadIO m) =>
    T.Text ->                               -- stock_id
    m MenuToolButton
menuToolButtonNewFromStock stock_id = liftIO $ do
    stock_id' <- textToCString stock_id
    result <- gtk_menu_tool_button_new_from_stock stock_id'
    checkUnexpectedReturnNULL "gtk_menu_tool_button_new_from_stock" result
    result' <- (newObject MenuToolButton) result
    freeMem stock_id'
    return result'

-- method MenuToolButton::get_menu
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "Widget"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_get_menu" gtk_menu_tool_button_get_menu :: 
    Ptr MenuToolButton ->                   -- _obj : TInterface "Gtk" "MenuToolButton"
    IO (Ptr Widget)


menuToolButtonGetMenu ::
    (MonadIO m, MenuToolButtonK a) =>
    a ->                                    -- _obj
    m Widget
menuToolButtonGetMenu _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_menu_tool_button_get_menu _obj'
    checkUnexpectedReturnNULL "gtk_menu_tool_button_get_menu" result
    result' <- (newObject Widget) result
    touchManagedPtr _obj
    return result'

-- method MenuToolButton::set_arrow_tooltip_markup
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "markup", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "markup", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_set_arrow_tooltip_markup" gtk_menu_tool_button_set_arrow_tooltip_markup :: 
    Ptr MenuToolButton ->                   -- _obj : TInterface "Gtk" "MenuToolButton"
    CString ->                              -- markup : TBasicType TUTF8
    IO ()


menuToolButtonSetArrowTooltipMarkup ::
    (MonadIO m, MenuToolButtonK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- markup
    m ()
menuToolButtonSetArrowTooltipMarkup _obj markup = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    markup' <- textToCString markup
    gtk_menu_tool_button_set_arrow_tooltip_markup _obj' markup'
    touchManagedPtr _obj
    freeMem markup'
    return ()

-- method MenuToolButton::set_arrow_tooltip_text
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "text", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "text", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_set_arrow_tooltip_text" gtk_menu_tool_button_set_arrow_tooltip_text :: 
    Ptr MenuToolButton ->                   -- _obj : TInterface "Gtk" "MenuToolButton"
    CString ->                              -- text : TBasicType TUTF8
    IO ()


menuToolButtonSetArrowTooltipText ::
    (MonadIO m, MenuToolButtonK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- text
    m ()
menuToolButtonSetArrowTooltipText _obj text = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    text' <- textToCString text
    gtk_menu_tool_button_set_arrow_tooltip_text _obj' text'
    touchManagedPtr _obj
    freeMem text'
    return ()

-- method MenuToolButton::set_menu
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "menu", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "MenuToolButton", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "menu", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_menu_tool_button_set_menu" gtk_menu_tool_button_set_menu :: 
    Ptr MenuToolButton ->                   -- _obj : TInterface "Gtk" "MenuToolButton"
    Ptr Widget ->                           -- menu : TInterface "Gtk" "Widget"
    IO ()


menuToolButtonSetMenu ::
    (MonadIO m, MenuToolButtonK a, WidgetK b) =>
    a ->                                    -- _obj
    b ->                                    -- menu
    m ()
menuToolButtonSetMenu _obj menu = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let menu' = unsafeManagedPtrCastPtr menu
    gtk_menu_tool_button_set_menu _obj' menu'
    touchManagedPtr _obj
    touchManagedPtr menu
    return ()


