
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.RendererCellAccessible
    ( 

-- * Exported types
    RendererCellAccessible(..)              ,
    RendererCellAccessibleK                 ,
    toRendererCellAccessible                ,
    noRendererCellAccessible                ,


 -- * Methods
-- ** rendererCellAccessibleNew
    rendererCellAccessibleNew               ,




 -- * Properties
-- ** Renderer
    RendererCellAccessibleRendererPropertyInfo,
    constructRendererCellAccessibleRenderer ,
    getRendererCellAccessibleRenderer       ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype RendererCellAccessible = RendererCellAccessible (ForeignPtr RendererCellAccessible)
foreign import ccall "gtk_renderer_cell_accessible_get_type"
    c_gtk_renderer_cell_accessible_get_type :: IO GType

type instance ParentTypes RendererCellAccessible = RendererCellAccessibleParentTypes
type RendererCellAccessibleParentTypes = '[CellAccessible, Accessible, Atk.Object, GObject.Object, Atk.Action, Atk.Component]

instance GObject RendererCellAccessible where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_gtk_renderer_cell_accessible_get_type
    

class GObject o => RendererCellAccessibleK o
instance (GObject o, IsDescendantOf RendererCellAccessible o) => RendererCellAccessibleK o

toRendererCellAccessible :: RendererCellAccessibleK o => o -> IO RendererCellAccessible
toRendererCellAccessible = unsafeCastTo RendererCellAccessible

noRendererCellAccessible :: Maybe RendererCellAccessible
noRendererCellAccessible = Nothing

-- VVV Prop "renderer"
   -- Type: TInterface "Gtk" "CellRenderer"
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstructOnly]

getRendererCellAccessibleRenderer :: (MonadIO m, RendererCellAccessibleK o) => o -> m CellRenderer
getRendererCellAccessibleRenderer obj = liftIO $ getObjectPropertyObject obj "renderer" CellRenderer

constructRendererCellAccessibleRenderer :: (CellRendererK a) => a -> IO ([Char], GValue)
constructRendererCellAccessibleRenderer val = constructObjectPropertyObject "renderer" val

data RendererCellAccessibleRendererPropertyInfo
instance AttrInfo RendererCellAccessibleRendererPropertyInfo where
    type AttrAllowedOps RendererCellAccessibleRendererPropertyInfo = '[ 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint RendererCellAccessibleRendererPropertyInfo = CellRendererK
    type AttrBaseTypeConstraint RendererCellAccessibleRendererPropertyInfo = RendererCellAccessibleK
    type AttrGetType RendererCellAccessibleRendererPropertyInfo = CellRenderer
    type AttrLabel RendererCellAccessibleRendererPropertyInfo = "RendererCellAccessible::renderer"
    attrGet _ = getRendererCellAccessibleRenderer
    attrSet _ = undefined
    attrConstruct _ = constructRendererCellAccessibleRenderer

type instance AttributeList RendererCellAccessible = RendererCellAccessibleAttributeList
type RendererCellAccessibleAttributeList = ('[ '("accessible-component-layer", Atk.ObjectAccessibleComponentLayerPropertyInfo), '("accessible-component-mdi-zorder", Atk.ObjectAccessibleComponentMdiZorderPropertyInfo), '("accessible-description", Atk.ObjectAccessibleDescriptionPropertyInfo), '("accessible-hypertext-nlinks", Atk.ObjectAccessibleHypertextNlinksPropertyInfo), '("accessible-name", Atk.ObjectAccessibleNamePropertyInfo), '("accessible-parent", Atk.ObjectAccessibleParentPropertyInfo), '("accessible-role", Atk.ObjectAccessibleRolePropertyInfo), '("accessible-table-caption", Atk.ObjectAccessibleTableCaptionPropertyInfo), '("accessible-table-caption-object", Atk.ObjectAccessibleTableCaptionObjectPropertyInfo), '("accessible-table-column-description", Atk.ObjectAccessibleTableColumnDescriptionPropertyInfo), '("accessible-table-column-header", Atk.ObjectAccessibleTableColumnHeaderPropertyInfo), '("accessible-table-row-description", Atk.ObjectAccessibleTableRowDescriptionPropertyInfo), '("accessible-table-row-header", Atk.ObjectAccessibleTableRowHeaderPropertyInfo), '("accessible-table-summary", Atk.ObjectAccessibleTableSummaryPropertyInfo), '("accessible-value", Atk.ObjectAccessibleValuePropertyInfo), '("renderer", RendererCellAccessibleRendererPropertyInfo), '("widget", AccessibleWidgetPropertyInfo)] :: [(Symbol, *)])

type instance SignalList RendererCellAccessible = RendererCellAccessibleSignalList
type RendererCellAccessibleSignalList = ('[ '("active-descendant-changed", Atk.ObjectActiveDescendantChangedSignalInfo), '("bounds-changed", Atk.ComponentBoundsChangedSignalInfo), '("children-changed", Atk.ObjectChildrenChangedSignalInfo), '("focus-event", Atk.ObjectFocusEventSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("property-change", Atk.ObjectPropertyChangeSignalInfo), '("state-change", Atk.ObjectStateChangeSignalInfo), '("visible-data-changed", Atk.ObjectVisibleDataChangedSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method RendererCellAccessible::new
-- method type : Constructor
-- Args : [Arg {argName = "renderer", argType = TInterface "Gtk" "CellRenderer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "renderer", argType = TInterface "Gtk" "CellRenderer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "RendererCellAccessible"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_renderer_cell_accessible_new" gtk_renderer_cell_accessible_new :: 
    Ptr CellRenderer ->                     -- renderer : TInterface "Gtk" "CellRenderer"
    IO (Ptr RendererCellAccessible)


rendererCellAccessibleNew ::
    (MonadIO m, CellRendererK a) =>
    a ->                                    -- renderer
    m RendererCellAccessible
rendererCellAccessibleNew renderer = liftIO $ do
    let renderer' = unsafeManagedPtrCastPtr renderer
    result <- gtk_renderer_cell_accessible_new renderer'
    checkUnexpectedReturnNULL "gtk_renderer_cell_accessible_new" result
    result' <- (wrapObject RendererCellAccessible) result
    touchManagedPtr renderer
    return result'


