
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.Revealer
    ( 

-- * Exported types
    Revealer(..)                            ,
    RevealerK                               ,
    toRevealer                              ,
    noRevealer                              ,


 -- * Methods
-- ** revealerGetChildRevealed
    revealerGetChildRevealed                ,


-- ** revealerGetRevealChild
    revealerGetRevealChild                  ,


-- ** revealerGetTransitionDuration
    revealerGetTransitionDuration           ,


-- ** revealerGetTransitionType
    revealerGetTransitionType               ,


-- ** revealerNew
    revealerNew                             ,


-- ** revealerSetRevealChild
    revealerSetRevealChild                  ,


-- ** revealerSetTransitionDuration
    revealerSetTransitionDuration           ,


-- ** revealerSetTransitionType
    revealerSetTransitionType               ,




 -- * Properties
-- ** ChildRevealed
    RevealerChildRevealedPropertyInfo       ,
    getRevealerChildRevealed                ,


-- ** RevealChild
    RevealerRevealChildPropertyInfo         ,
    constructRevealerRevealChild            ,
    getRevealerRevealChild                  ,
    setRevealerRevealChild                  ,


-- ** TransitionDuration
    RevealerTransitionDurationPropertyInfo  ,
    constructRevealerTransitionDuration     ,
    getRevealerTransitionDuration           ,
    setRevealerTransitionDuration           ,


-- ** TransitionType
    RevealerTransitionTypePropertyInfo      ,
    constructRevealerTransitionType         ,
    getRevealerTransitionType               ,
    setRevealerTransitionType               ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype Revealer = Revealer (ForeignPtr Revealer)
foreign import ccall "gtk_revealer_get_type"
    c_gtk_revealer_get_type :: IO GType

type instance ParentTypes Revealer = RevealerParentTypes
type RevealerParentTypes = '[Bin, Container, Widget, GObject.Object, Atk.ImplementorIface, Buildable]

instance GObject Revealer where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_revealer_get_type
    

class GObject o => RevealerK o
instance (GObject o, IsDescendantOf Revealer o) => RevealerK o

toRevealer :: RevealerK o => o -> IO Revealer
toRevealer = unsafeCastTo Revealer

noRevealer :: Maybe Revealer
noRevealer = Nothing

-- VVV Prop "child-revealed"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable]

getRevealerChildRevealed :: (MonadIO m, RevealerK o) => o -> m Bool
getRevealerChildRevealed obj = liftIO $ getObjectPropertyBool obj "child-revealed"

data RevealerChildRevealedPropertyInfo
instance AttrInfo RevealerChildRevealedPropertyInfo where
    type AttrAllowedOps RevealerChildRevealedPropertyInfo = '[ 'AttrGet]
    type AttrSetTypeConstraint RevealerChildRevealedPropertyInfo = (~) ()
    type AttrBaseTypeConstraint RevealerChildRevealedPropertyInfo = RevealerK
    type AttrGetType RevealerChildRevealedPropertyInfo = Bool
    type AttrLabel RevealerChildRevealedPropertyInfo = "Revealer::child-revealed"
    attrGet _ = getRevealerChildRevealed
    attrSet _ = undefined
    attrConstruct _ = undefined

-- VVV Prop "reveal-child"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstruct]

getRevealerRevealChild :: (MonadIO m, RevealerK o) => o -> m Bool
getRevealerRevealChild obj = liftIO $ getObjectPropertyBool obj "reveal-child"

setRevealerRevealChild :: (MonadIO m, RevealerK o) => o -> Bool -> m ()
setRevealerRevealChild obj val = liftIO $ setObjectPropertyBool obj "reveal-child" val

constructRevealerRevealChild :: Bool -> IO ([Char], GValue)
constructRevealerRevealChild val = constructObjectPropertyBool "reveal-child" val

data RevealerRevealChildPropertyInfo
instance AttrInfo RevealerRevealChildPropertyInfo where
    type AttrAllowedOps RevealerRevealChildPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint RevealerRevealChildPropertyInfo = (~) Bool
    type AttrBaseTypeConstraint RevealerRevealChildPropertyInfo = RevealerK
    type AttrGetType RevealerRevealChildPropertyInfo = Bool
    type AttrLabel RevealerRevealChildPropertyInfo = "Revealer::reveal-child"
    attrGet _ = getRevealerRevealChild
    attrSet _ = setRevealerRevealChild
    attrConstruct _ = constructRevealerRevealChild

-- VVV Prop "transition-duration"
   -- Type: TBasicType TUInt32
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstruct]

getRevealerTransitionDuration :: (MonadIO m, RevealerK o) => o -> m Word32
getRevealerTransitionDuration obj = liftIO $ getObjectPropertyCUInt obj "transition-duration"

setRevealerTransitionDuration :: (MonadIO m, RevealerK o) => o -> Word32 -> m ()
setRevealerTransitionDuration obj val = liftIO $ setObjectPropertyCUInt obj "transition-duration" val

constructRevealerTransitionDuration :: Word32 -> IO ([Char], GValue)
constructRevealerTransitionDuration val = constructObjectPropertyCUInt "transition-duration" val

data RevealerTransitionDurationPropertyInfo
instance AttrInfo RevealerTransitionDurationPropertyInfo where
    type AttrAllowedOps RevealerTransitionDurationPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint RevealerTransitionDurationPropertyInfo = (~) Word32
    type AttrBaseTypeConstraint RevealerTransitionDurationPropertyInfo = RevealerK
    type AttrGetType RevealerTransitionDurationPropertyInfo = Word32
    type AttrLabel RevealerTransitionDurationPropertyInfo = "Revealer::transition-duration"
    attrGet _ = getRevealerTransitionDuration
    attrSet _ = setRevealerTransitionDuration
    attrConstruct _ = constructRevealerTransitionDuration

-- VVV Prop "transition-type"
   -- Type: TInterface "Gtk" "RevealerTransitionType"
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstruct]

getRevealerTransitionType :: (MonadIO m, RevealerK o) => o -> m RevealerTransitionType
getRevealerTransitionType obj = liftIO $ getObjectPropertyEnum obj "transition-type"

setRevealerTransitionType :: (MonadIO m, RevealerK o) => o -> RevealerTransitionType -> m ()
setRevealerTransitionType obj val = liftIO $ setObjectPropertyEnum obj "transition-type" val

constructRevealerTransitionType :: RevealerTransitionType -> IO ([Char], GValue)
constructRevealerTransitionType val = constructObjectPropertyEnum "transition-type" val

data RevealerTransitionTypePropertyInfo
instance AttrInfo RevealerTransitionTypePropertyInfo where
    type AttrAllowedOps RevealerTransitionTypePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint RevealerTransitionTypePropertyInfo = (~) RevealerTransitionType
    type AttrBaseTypeConstraint RevealerTransitionTypePropertyInfo = RevealerK
    type AttrGetType RevealerTransitionTypePropertyInfo = RevealerTransitionType
    type AttrLabel RevealerTransitionTypePropertyInfo = "Revealer::transition-type"
    attrGet _ = getRevealerTransitionType
    attrSet _ = setRevealerTransitionType
    attrConstruct _ = constructRevealerTransitionType

type instance AttributeList Revealer = RevealerAttributeList
type RevealerAttributeList = ('[ '("app-paintable", WidgetAppPaintablePropertyInfo), '("border-width", ContainerBorderWidthPropertyInfo), '("can-default", WidgetCanDefaultPropertyInfo), '("can-focus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("child-revealed", RevealerChildRevealedPropertyInfo), '("composite-child", WidgetCompositeChildPropertyInfo), '("double-buffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("has-default", WidgetHasDefaultPropertyInfo), '("has-focus", WidgetHasFocusPropertyInfo), '("has-tooltip", WidgetHasTooltipPropertyInfo), '("height-request", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpand-set", WidgetHexpandSetPropertyInfo), '("is-focus", WidgetIsFocusPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("margin-bottom", WidgetMarginBottomPropertyInfo), '("margin-end", WidgetMarginEndPropertyInfo), '("margin-left", WidgetMarginLeftPropertyInfo), '("margin-right", WidgetMarginRightPropertyInfo), '("margin-start", WidgetMarginStartPropertyInfo), '("margin-top", WidgetMarginTopPropertyInfo), '("name", WidgetNamePropertyInfo), '("no-show-all", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receives-default", WidgetReceivesDefaultPropertyInfo), '("resize-mode", ContainerResizeModePropertyInfo), '("reveal-child", RevealerRevealChildPropertyInfo), '("scale-factor", WidgetScaleFactorPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("style", WidgetStylePropertyInfo), '("tooltip-markup", WidgetTooltipMarkupPropertyInfo), '("tooltip-text", WidgetTooltipTextPropertyInfo), '("transition-duration", RevealerTransitionDurationPropertyInfo), '("transition-type", RevealerTransitionTypePropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpand-set", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("width-request", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo)] :: [(Symbol, *)])

type instance SignalList Revealer = RevealerSignalList
type RevealerSignalList = ('[ '("accel-closures-changed", WidgetAccelClosuresChangedSignalInfo), '("add", ContainerAddSignalInfo), '("button-press-event", WidgetButtonPressEventSignalInfo), '("button-release-event", WidgetButtonReleaseEventSignalInfo), '("can-activate-accel", WidgetCanActivateAccelSignalInfo), '("check-resize", ContainerCheckResizeSignalInfo), '("child-notify", WidgetChildNotifySignalInfo), '("composited-changed", WidgetCompositedChangedSignalInfo), '("configure-event", WidgetConfigureEventSignalInfo), '("damage-event", WidgetDamageEventSignalInfo), '("delete-event", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroy-event", WidgetDestroyEventSignalInfo), '("direction-changed", WidgetDirectionChangedSignalInfo), '("drag-begin", WidgetDragBeginSignalInfo), '("drag-data-delete", WidgetDragDataDeleteSignalInfo), '("drag-data-get", WidgetDragDataGetSignalInfo), '("drag-data-received", WidgetDragDataReceivedSignalInfo), '("drag-drop", WidgetDragDropSignalInfo), '("drag-end", WidgetDragEndSignalInfo), '("drag-failed", WidgetDragFailedSignalInfo), '("drag-leave", WidgetDragLeaveSignalInfo), '("drag-motion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enter-notify-event", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("event-after", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focus-in-event", WidgetFocusInEventSignalInfo), '("focus-out-event", WidgetFocusOutEventSignalInfo), '("grab-broken-event", WidgetGrabBrokenEventSignalInfo), '("grab-focus", WidgetGrabFocusSignalInfo), '("grab-notify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchy-changed", WidgetHierarchyChangedSignalInfo), '("key-press-event", WidgetKeyPressEventSignalInfo), '("key-release-event", WidgetKeyReleaseEventSignalInfo), '("keynav-failed", WidgetKeynavFailedSignalInfo), '("leave-notify-event", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("map-event", WidgetMapEventSignalInfo), '("mnemonic-activate", WidgetMnemonicActivateSignalInfo), '("motion-notify-event", WidgetMotionNotifyEventSignalInfo), '("move-focus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parent-set", WidgetParentSetSignalInfo), '("popup-menu", WidgetPopupMenuSignalInfo), '("property-notify-event", WidgetPropertyNotifyEventSignalInfo), '("proximity-in-event", WidgetProximityInEventSignalInfo), '("proximity-out-event", WidgetProximityOutEventSignalInfo), '("query-tooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screen-changed", WidgetScreenChangedSignalInfo), '("scroll-event", WidgetScrollEventSignalInfo), '("selection-clear-event", WidgetSelectionClearEventSignalInfo), '("selection-get", WidgetSelectionGetSignalInfo), '("selection-notify-event", WidgetSelectionNotifyEventSignalInfo), '("selection-received", WidgetSelectionReceivedSignalInfo), '("selection-request-event", WidgetSelectionRequestEventSignalInfo), '("set-focus-child", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("show-help", WidgetShowHelpSignalInfo), '("size-allocate", WidgetSizeAllocateSignalInfo), '("state-changed", WidgetStateChangedSignalInfo), '("state-flags-changed", WidgetStateFlagsChangedSignalInfo), '("style-set", WidgetStyleSetSignalInfo), '("style-updated", WidgetStyleUpdatedSignalInfo), '("touch-event", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmap-event", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibility-notify-event", WidgetVisibilityNotifyEventSignalInfo), '("window-state-event", WidgetWindowStateEventSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method Revealer::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- hInArgs : []
-- returnType : TInterface "Gtk" "Revealer"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_new" gtk_revealer_new :: 
    IO (Ptr Revealer)


revealerNew ::
    (MonadIO m) =>
    m Revealer
revealerNew  = liftIO $ do
    result <- gtk_revealer_new
    checkUnexpectedReturnNULL "gtk_revealer_new" result
    result' <- (newObject Revealer) result
    return result'

-- method Revealer::get_child_revealed
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_get_child_revealed" gtk_revealer_get_child_revealed :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    IO CInt


revealerGetChildRevealed ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    m Bool
revealerGetChildRevealed _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_revealer_get_child_revealed _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method Revealer::get_reveal_child
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_get_reveal_child" gtk_revealer_get_reveal_child :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    IO CInt


revealerGetRevealChild ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    m Bool
revealerGetRevealChild _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_revealer_get_reveal_child _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method Revealer::get_transition_duration
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_get_transition_duration" gtk_revealer_get_transition_duration :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    IO Word32


revealerGetTransitionDuration ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    m Word32
revealerGetTransitionDuration _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_revealer_get_transition_duration _obj'
    touchManagedPtr _obj
    return result

-- method Revealer::get_transition_type
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "RevealerTransitionType"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_get_transition_type" gtk_revealer_get_transition_type :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    IO CUInt


revealerGetTransitionType ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    m RevealerTransitionType
revealerGetTransitionType _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_revealer_get_transition_type _obj'
    let result' = (toEnum . fromIntegral) result
    touchManagedPtr _obj
    return result'

-- method Revealer::set_reveal_child
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "reveal_child", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "reveal_child", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_set_reveal_child" gtk_revealer_set_reveal_child :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    CInt ->                                 -- reveal_child : TBasicType TBoolean
    IO ()


revealerSetRevealChild ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    Bool ->                                 -- reveal_child
    m ()
revealerSetRevealChild _obj reveal_child = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let reveal_child' = (fromIntegral . fromEnum) reveal_child
    gtk_revealer_set_reveal_child _obj' reveal_child'
    touchManagedPtr _obj
    return ()

-- method Revealer::set_transition_duration
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "duration", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "duration", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_set_transition_duration" gtk_revealer_set_transition_duration :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    Word32 ->                               -- duration : TBasicType TUInt32
    IO ()


revealerSetTransitionDuration ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- duration
    m ()
revealerSetTransitionDuration _obj duration = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_revealer_set_transition_duration _obj' duration
    touchManagedPtr _obj
    return ()

-- method Revealer::set_transition_type
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "transition", argType = TInterface "Gtk" "RevealerTransitionType", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Revealer", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "transition", argType = TInterface "Gtk" "RevealerTransitionType", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_revealer_set_transition_type" gtk_revealer_set_transition_type :: 
    Ptr Revealer ->                         -- _obj : TInterface "Gtk" "Revealer"
    CUInt ->                                -- transition : TInterface "Gtk" "RevealerTransitionType"
    IO ()


revealerSetTransitionType ::
    (MonadIO m, RevealerK a) =>
    a ->                                    -- _obj
    RevealerTransitionType ->               -- transition
    m ()
revealerSetTransitionType _obj transition = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let transition' = (fromIntegral . fromEnum) transition
    gtk_revealer_set_transition_type _obj' transition'
    touchManagedPtr _obj
    return ()


