
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.Table
    ( 

-- * Exported types
    Table(..)                               ,
    TableK                                  ,
    toTable                                 ,
    noTable                                 ,


 -- * Methods
-- ** tableAttach
    tableAttach                             ,


-- ** tableAttachDefaults
    tableAttachDefaults                     ,


-- ** tableGetColSpacing
    tableGetColSpacing                      ,


-- ** tableGetDefaultColSpacing
    tableGetDefaultColSpacing               ,


-- ** tableGetDefaultRowSpacing
    tableGetDefaultRowSpacing               ,


-- ** tableGetHomogeneous
    tableGetHomogeneous                     ,


-- ** tableGetRowSpacing
    tableGetRowSpacing                      ,


-- ** tableGetSize
    tableGetSize                            ,


-- ** tableNew
    tableNew                                ,


-- ** tableResize
    tableResize                             ,


-- ** tableSetColSpacing
    tableSetColSpacing                      ,


-- ** tableSetColSpacings
    tableSetColSpacings                     ,


-- ** tableSetHomogeneous
    tableSetHomogeneous                     ,


-- ** tableSetRowSpacing
    tableSetRowSpacing                      ,


-- ** tableSetRowSpacings
    tableSetRowSpacings                     ,




 -- * Properties
-- ** ColumnSpacing
    TableColumnSpacingPropertyInfo          ,
    constructTableColumnSpacing             ,
    getTableColumnSpacing                   ,
    setTableColumnSpacing                   ,


-- ** Homogeneous
    TableHomogeneousPropertyInfo            ,
    constructTableHomogeneous               ,
    getTableHomogeneous                     ,
    setTableHomogeneous                     ,


-- ** NColumns
    TableNColumnsPropertyInfo               ,
    constructTableNColumns                  ,
    getTableNColumns                        ,
    setTableNColumns                        ,


-- ** NRows
    TableNRowsPropertyInfo                  ,
    constructTableNRows                     ,
    getTableNRows                           ,
    setTableNRows                           ,


-- ** RowSpacing
    TableRowSpacingPropertyInfo             ,
    constructTableRowSpacing                ,
    getTableRowSpacing                      ,
    setTableRowSpacing                      ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype Table = Table (ForeignPtr Table)
foreign import ccall "gtk_table_get_type"
    c_gtk_table_get_type :: IO GType

type instance ParentTypes Table = TableParentTypes
type TableParentTypes = '[Container, Widget, GObject.Object, Atk.ImplementorIface, Buildable]

instance GObject Table where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_table_get_type
    

class GObject o => TableK o
instance (GObject o, IsDescendantOf Table o) => TableK o

toTable :: TableK o => o -> IO Table
toTable = unsafeCastTo Table

noTable :: Maybe Table
noTable = Nothing

-- VVV Prop "column-spacing"
   -- Type: TBasicType TUInt32
   -- Flags: [PropertyReadable,PropertyWritable]

getTableColumnSpacing :: (MonadIO m, TableK o) => o -> m Word32
getTableColumnSpacing obj = liftIO $ getObjectPropertyCUInt obj "column-spacing"

setTableColumnSpacing :: (MonadIO m, TableK o) => o -> Word32 -> m ()
setTableColumnSpacing obj val = liftIO $ setObjectPropertyCUInt obj "column-spacing" val

constructTableColumnSpacing :: Word32 -> IO ([Char], GValue)
constructTableColumnSpacing val = constructObjectPropertyCUInt "column-spacing" val

data TableColumnSpacingPropertyInfo
instance AttrInfo TableColumnSpacingPropertyInfo where
    type AttrAllowedOps TableColumnSpacingPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint TableColumnSpacingPropertyInfo = (~) Word32
    type AttrBaseTypeConstraint TableColumnSpacingPropertyInfo = TableK
    type AttrGetType TableColumnSpacingPropertyInfo = Word32
    type AttrLabel TableColumnSpacingPropertyInfo = "Table::column-spacing"
    attrGet _ = getTableColumnSpacing
    attrSet _ = setTableColumnSpacing
    attrConstruct _ = constructTableColumnSpacing

-- VVV Prop "homogeneous"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable,PropertyWritable]

getTableHomogeneous :: (MonadIO m, TableK o) => o -> m Bool
getTableHomogeneous obj = liftIO $ getObjectPropertyBool obj "homogeneous"

setTableHomogeneous :: (MonadIO m, TableK o) => o -> Bool -> m ()
setTableHomogeneous obj val = liftIO $ setObjectPropertyBool obj "homogeneous" val

constructTableHomogeneous :: Bool -> IO ([Char], GValue)
constructTableHomogeneous val = constructObjectPropertyBool "homogeneous" val

data TableHomogeneousPropertyInfo
instance AttrInfo TableHomogeneousPropertyInfo where
    type AttrAllowedOps TableHomogeneousPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint TableHomogeneousPropertyInfo = (~) Bool
    type AttrBaseTypeConstraint TableHomogeneousPropertyInfo = TableK
    type AttrGetType TableHomogeneousPropertyInfo = Bool
    type AttrLabel TableHomogeneousPropertyInfo = "Table::homogeneous"
    attrGet _ = getTableHomogeneous
    attrSet _ = setTableHomogeneous
    attrConstruct _ = constructTableHomogeneous

-- VVV Prop "n-columns"
   -- Type: TBasicType TUInt32
   -- Flags: [PropertyReadable,PropertyWritable]

getTableNColumns :: (MonadIO m, TableK o) => o -> m Word32
getTableNColumns obj = liftIO $ getObjectPropertyCUInt obj "n-columns"

setTableNColumns :: (MonadIO m, TableK o) => o -> Word32 -> m ()
setTableNColumns obj val = liftIO $ setObjectPropertyCUInt obj "n-columns" val

constructTableNColumns :: Word32 -> IO ([Char], GValue)
constructTableNColumns val = constructObjectPropertyCUInt "n-columns" val

data TableNColumnsPropertyInfo
instance AttrInfo TableNColumnsPropertyInfo where
    type AttrAllowedOps TableNColumnsPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint TableNColumnsPropertyInfo = (~) Word32
    type AttrBaseTypeConstraint TableNColumnsPropertyInfo = TableK
    type AttrGetType TableNColumnsPropertyInfo = Word32
    type AttrLabel TableNColumnsPropertyInfo = "Table::n-columns"
    attrGet _ = getTableNColumns
    attrSet _ = setTableNColumns
    attrConstruct _ = constructTableNColumns

-- VVV Prop "n-rows"
   -- Type: TBasicType TUInt32
   -- Flags: [PropertyReadable,PropertyWritable]

getTableNRows :: (MonadIO m, TableK o) => o -> m Word32
getTableNRows obj = liftIO $ getObjectPropertyCUInt obj "n-rows"

setTableNRows :: (MonadIO m, TableK o) => o -> Word32 -> m ()
setTableNRows obj val = liftIO $ setObjectPropertyCUInt obj "n-rows" val

constructTableNRows :: Word32 -> IO ([Char], GValue)
constructTableNRows val = constructObjectPropertyCUInt "n-rows" val

data TableNRowsPropertyInfo
instance AttrInfo TableNRowsPropertyInfo where
    type AttrAllowedOps TableNRowsPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint TableNRowsPropertyInfo = (~) Word32
    type AttrBaseTypeConstraint TableNRowsPropertyInfo = TableK
    type AttrGetType TableNRowsPropertyInfo = Word32
    type AttrLabel TableNRowsPropertyInfo = "Table::n-rows"
    attrGet _ = getTableNRows
    attrSet _ = setTableNRows
    attrConstruct _ = constructTableNRows

-- VVV Prop "row-spacing"
   -- Type: TBasicType TUInt32
   -- Flags: [PropertyReadable,PropertyWritable]

getTableRowSpacing :: (MonadIO m, TableK o) => o -> m Word32
getTableRowSpacing obj = liftIO $ getObjectPropertyCUInt obj "row-spacing"

setTableRowSpacing :: (MonadIO m, TableK o) => o -> Word32 -> m ()
setTableRowSpacing obj val = liftIO $ setObjectPropertyCUInt obj "row-spacing" val

constructTableRowSpacing :: Word32 -> IO ([Char], GValue)
constructTableRowSpacing val = constructObjectPropertyCUInt "row-spacing" val

data TableRowSpacingPropertyInfo
instance AttrInfo TableRowSpacingPropertyInfo where
    type AttrAllowedOps TableRowSpacingPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint TableRowSpacingPropertyInfo = (~) Word32
    type AttrBaseTypeConstraint TableRowSpacingPropertyInfo = TableK
    type AttrGetType TableRowSpacingPropertyInfo = Word32
    type AttrLabel TableRowSpacingPropertyInfo = "Table::row-spacing"
    attrGet _ = getTableRowSpacing
    attrSet _ = setTableRowSpacing
    attrConstruct _ = constructTableRowSpacing

type instance AttributeList Table = TableAttributeList
type TableAttributeList = ('[ '("app-paintable", WidgetAppPaintablePropertyInfo), '("border-width", ContainerBorderWidthPropertyInfo), '("can-default", WidgetCanDefaultPropertyInfo), '("can-focus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("column-spacing", TableColumnSpacingPropertyInfo), '("composite-child", WidgetCompositeChildPropertyInfo), '("double-buffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("has-default", WidgetHasDefaultPropertyInfo), '("has-focus", WidgetHasFocusPropertyInfo), '("has-tooltip", WidgetHasTooltipPropertyInfo), '("height-request", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpand-set", WidgetHexpandSetPropertyInfo), '("homogeneous", TableHomogeneousPropertyInfo), '("is-focus", WidgetIsFocusPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("margin-bottom", WidgetMarginBottomPropertyInfo), '("margin-end", WidgetMarginEndPropertyInfo), '("margin-left", WidgetMarginLeftPropertyInfo), '("margin-right", WidgetMarginRightPropertyInfo), '("margin-start", WidgetMarginStartPropertyInfo), '("margin-top", WidgetMarginTopPropertyInfo), '("n-columns", TableNColumnsPropertyInfo), '("n-rows", TableNRowsPropertyInfo), '("name", WidgetNamePropertyInfo), '("no-show-all", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receives-default", WidgetReceivesDefaultPropertyInfo), '("resize-mode", ContainerResizeModePropertyInfo), '("row-spacing", TableRowSpacingPropertyInfo), '("scale-factor", WidgetScaleFactorPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("style", WidgetStylePropertyInfo), '("tooltip-markup", WidgetTooltipMarkupPropertyInfo), '("tooltip-text", WidgetTooltipTextPropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpand-set", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("width-request", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo)] :: [(Symbol, *)])

type instance SignalList Table = TableSignalList
type TableSignalList = ('[ '("accel-closures-changed", WidgetAccelClosuresChangedSignalInfo), '("add", ContainerAddSignalInfo), '("button-press-event", WidgetButtonPressEventSignalInfo), '("button-release-event", WidgetButtonReleaseEventSignalInfo), '("can-activate-accel", WidgetCanActivateAccelSignalInfo), '("check-resize", ContainerCheckResizeSignalInfo), '("child-notify", WidgetChildNotifySignalInfo), '("composited-changed", WidgetCompositedChangedSignalInfo), '("configure-event", WidgetConfigureEventSignalInfo), '("damage-event", WidgetDamageEventSignalInfo), '("delete-event", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroy-event", WidgetDestroyEventSignalInfo), '("direction-changed", WidgetDirectionChangedSignalInfo), '("drag-begin", WidgetDragBeginSignalInfo), '("drag-data-delete", WidgetDragDataDeleteSignalInfo), '("drag-data-get", WidgetDragDataGetSignalInfo), '("drag-data-received", WidgetDragDataReceivedSignalInfo), '("drag-drop", WidgetDragDropSignalInfo), '("drag-end", WidgetDragEndSignalInfo), '("drag-failed", WidgetDragFailedSignalInfo), '("drag-leave", WidgetDragLeaveSignalInfo), '("drag-motion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enter-notify-event", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("event-after", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focus-in-event", WidgetFocusInEventSignalInfo), '("focus-out-event", WidgetFocusOutEventSignalInfo), '("grab-broken-event", WidgetGrabBrokenEventSignalInfo), '("grab-focus", WidgetGrabFocusSignalInfo), '("grab-notify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchy-changed", WidgetHierarchyChangedSignalInfo), '("key-press-event", WidgetKeyPressEventSignalInfo), '("key-release-event", WidgetKeyReleaseEventSignalInfo), '("keynav-failed", WidgetKeynavFailedSignalInfo), '("leave-notify-event", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("map-event", WidgetMapEventSignalInfo), '("mnemonic-activate", WidgetMnemonicActivateSignalInfo), '("motion-notify-event", WidgetMotionNotifyEventSignalInfo), '("move-focus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parent-set", WidgetParentSetSignalInfo), '("popup-menu", WidgetPopupMenuSignalInfo), '("property-notify-event", WidgetPropertyNotifyEventSignalInfo), '("proximity-in-event", WidgetProximityInEventSignalInfo), '("proximity-out-event", WidgetProximityOutEventSignalInfo), '("query-tooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screen-changed", WidgetScreenChangedSignalInfo), '("scroll-event", WidgetScrollEventSignalInfo), '("selection-clear-event", WidgetSelectionClearEventSignalInfo), '("selection-get", WidgetSelectionGetSignalInfo), '("selection-notify-event", WidgetSelectionNotifyEventSignalInfo), '("selection-received", WidgetSelectionReceivedSignalInfo), '("selection-request-event", WidgetSelectionRequestEventSignalInfo), '("set-focus-child", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("show-help", WidgetShowHelpSignalInfo), '("size-allocate", WidgetSizeAllocateSignalInfo), '("state-changed", WidgetStateChangedSignalInfo), '("state-flags-changed", WidgetStateFlagsChangedSignalInfo), '("style-set", WidgetStyleSetSignalInfo), '("style-updated", WidgetStyleUpdatedSignalInfo), '("touch-event", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmap-event", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibility-notify-event", WidgetVisibilityNotifyEventSignalInfo), '("window-state-event", WidgetWindowStateEventSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method Table::new
-- method type : Constructor
-- Args : [Arg {argName = "rows", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "columns", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "homogeneous", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "rows", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "columns", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "homogeneous", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Gtk" "Table"
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_new" gtk_table_new :: 
    Word32 ->                               -- rows : TBasicType TUInt32
    Word32 ->                               -- columns : TBasicType TUInt32
    CInt ->                                 -- homogeneous : TBasicType TBoolean
    IO (Ptr Table)

{-# DEPRECATED tableNew ["(Since version 3.4)","Use gtk_grid_new()."]#-}
tableNew ::
    (MonadIO m) =>
    Word32 ->                               -- rows
    Word32 ->                               -- columns
    Bool ->                                 -- homogeneous
    m Table
tableNew rows columns homogeneous = liftIO $ do
    let homogeneous' = (fromIntegral . fromEnum) homogeneous
    result <- gtk_table_new rows columns homogeneous'
    checkUnexpectedReturnNULL "gtk_table_new" result
    result' <- (newObject Table) result
    return result'

-- method Table::attach
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "child", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "left_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "right_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "top_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "bottom_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "xoptions", argType = TInterface "Gtk" "AttachOptions", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "yoptions", argType = TInterface "Gtk" "AttachOptions", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "xpadding", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "ypadding", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "child", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "left_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "right_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "top_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "bottom_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "xoptions", argType = TInterface "Gtk" "AttachOptions", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "yoptions", argType = TInterface "Gtk" "AttachOptions", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "xpadding", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "ypadding", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_attach" gtk_table_attach :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Ptr Widget ->                           -- child : TInterface "Gtk" "Widget"
    Word32 ->                               -- left_attach : TBasicType TUInt32
    Word32 ->                               -- right_attach : TBasicType TUInt32
    Word32 ->                               -- top_attach : TBasicType TUInt32
    Word32 ->                               -- bottom_attach : TBasicType TUInt32
    CUInt ->                                -- xoptions : TInterface "Gtk" "AttachOptions"
    CUInt ->                                -- yoptions : TInterface "Gtk" "AttachOptions"
    Word32 ->                               -- xpadding : TBasicType TUInt32
    Word32 ->                               -- ypadding : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableAttach ["(Since version 3.4)","Use gtk_grid_attach() with #GtkGrid. Note that the attach","    arguments differ between those two functions."]#-}
tableAttach ::
    (MonadIO m, TableK a, WidgetK b) =>
    a ->                                    -- _obj
    b ->                                    -- child
    Word32 ->                               -- left_attach
    Word32 ->                               -- right_attach
    Word32 ->                               -- top_attach
    Word32 ->                               -- bottom_attach
    [AttachOptions] ->                      -- xoptions
    [AttachOptions] ->                      -- yoptions
    Word32 ->                               -- xpadding
    Word32 ->                               -- ypadding
    m ()
tableAttach _obj child left_attach right_attach top_attach bottom_attach xoptions yoptions xpadding ypadding = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let child' = unsafeManagedPtrCastPtr child
    let xoptions' = gflagsToWord xoptions
    let yoptions' = gflagsToWord yoptions
    gtk_table_attach _obj' child' left_attach right_attach top_attach bottom_attach xoptions' yoptions' xpadding ypadding
    touchManagedPtr _obj
    touchManagedPtr child
    return ()

-- method Table::attach_defaults
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "left_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "right_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "top_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "bottom_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "widget", argType = TInterface "Gtk" "Widget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "left_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "right_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "top_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "bottom_attach", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_attach_defaults" gtk_table_attach_defaults :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Ptr Widget ->                           -- widget : TInterface "Gtk" "Widget"
    Word32 ->                               -- left_attach : TBasicType TUInt32
    Word32 ->                               -- right_attach : TBasicType TUInt32
    Word32 ->                               -- top_attach : TBasicType TUInt32
    Word32 ->                               -- bottom_attach : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableAttachDefaults ["(Since version 3.4)","Use gtk_grid_attach() with #GtkGrid. Note that the attach","    arguments differ between those two functions."]#-}
tableAttachDefaults ::
    (MonadIO m, TableK a, WidgetK b) =>
    a ->                                    -- _obj
    b ->                                    -- widget
    Word32 ->                               -- left_attach
    Word32 ->                               -- right_attach
    Word32 ->                               -- top_attach
    Word32 ->                               -- bottom_attach
    m ()
tableAttachDefaults _obj widget left_attach right_attach top_attach bottom_attach = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let widget' = unsafeManagedPtrCastPtr widget
    gtk_table_attach_defaults _obj' widget' left_attach right_attach top_attach bottom_attach
    touchManagedPtr _obj
    touchManagedPtr widget
    return ()

-- method Table::get_col_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "column", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "column", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_col_spacing" gtk_table_get_col_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- column : TBasicType TUInt32
    IO Word32

{-# DEPRECATED tableGetColSpacing ["(Since version 3.4)","#GtkGrid does not offer a replacement for this","    functionality."]#-}
tableGetColSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- column
    m Word32
tableGetColSpacing _obj column = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_table_get_col_spacing _obj' column
    touchManagedPtr _obj
    return result

-- method Table::get_default_col_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_default_col_spacing" gtk_table_get_default_col_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    IO Word32

{-# DEPRECATED tableGetDefaultColSpacing ["(Since version 3.4)","Use gtk_grid_get_column_spacing() with #GtkGrid."]#-}
tableGetDefaultColSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    m Word32
tableGetDefaultColSpacing _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_table_get_default_col_spacing _obj'
    touchManagedPtr _obj
    return result

-- method Table::get_default_row_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_default_row_spacing" gtk_table_get_default_row_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    IO Word32

{-# DEPRECATED tableGetDefaultRowSpacing ["(Since version 3.4)","Use gtk_grid_get_row_spacing() with #GtkGrid."]#-}
tableGetDefaultRowSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    m Word32
tableGetDefaultRowSpacing _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_table_get_default_row_spacing _obj'
    touchManagedPtr _obj
    return result

-- method Table::get_homogeneous
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_homogeneous" gtk_table_get_homogeneous :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    IO CInt

{-# DEPRECATED tableGetHomogeneous ["(Since version 3.4)","Use gtk_grid_get_row_homogeneous() and","    gtk_grid_get_column_homogeneous() with #GtkGrid."]#-}
tableGetHomogeneous ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    m Bool
tableGetHomogeneous _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_table_get_homogeneous _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

-- method Table::get_row_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "row", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "row", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUInt32
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_row_spacing" gtk_table_get_row_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- row : TBasicType TUInt32
    IO Word32

{-# DEPRECATED tableGetRowSpacing ["(Since version 3.4)","#GtkGrid does not offer a replacement for this","    functionality."]#-}
tableGetRowSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- row
    m Word32
tableGetRowSpacing _obj row = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_table_get_row_spacing _obj' row
    touchManagedPtr _obj
    return result

-- method Table::get_size
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "rows", argType = TBasicType TUInt32, direction = DirectionOut, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferEverything},Arg {argName = "columns", argType = TBasicType TUInt32, direction = DirectionOut, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferEverything}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_get_size" gtk_table_get_size :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Ptr Word32 ->                           -- rows : TBasicType TUInt32
    Ptr Word32 ->                           -- columns : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableGetSize ["(Since version 3.4)","#GtkGrid does not expose the number of columns and","    rows."]#-}
tableGetSize ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    m (Word32,Word32)
tableGetSize _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    rows <- allocMem :: IO (Ptr Word32)
    columns <- allocMem :: IO (Ptr Word32)
    gtk_table_get_size _obj' rows columns
    rows' <- peek rows
    columns' <- peek columns
    touchManagedPtr _obj
    freeMem rows
    freeMem columns
    return (rows', columns')

-- method Table::resize
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "rows", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "columns", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "rows", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "columns", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_resize" gtk_table_resize :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- rows : TBasicType TUInt32
    Word32 ->                               -- columns : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableResize ["(Since version 3.4)","#GtkGrid resizes automatically."]#-}
tableResize ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- rows
    Word32 ->                               -- columns
    m ()
tableResize _obj rows columns = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_table_resize _obj' rows columns
    touchManagedPtr _obj
    return ()

-- method Table::set_col_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "column", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "column", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_set_col_spacing" gtk_table_set_col_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- column : TBasicType TUInt32
    Word32 ->                               -- spacing : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableSetColSpacing ["(Since version 3.4)","Use gtk_widget_set_margin_start() and","    gtk_widget_set_margin_end() on the widgets contained in the row if","    you need this functionality. #GtkGrid does not support per-row spacing."]#-}
tableSetColSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- column
    Word32 ->                               -- spacing
    m ()
tableSetColSpacing _obj column spacing = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_table_set_col_spacing _obj' column spacing
    touchManagedPtr _obj
    return ()

-- method Table::set_col_spacings
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_set_col_spacings" gtk_table_set_col_spacings :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- spacing : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableSetColSpacings ["(Since version 3.4)","Use gtk_grid_set_column_spacing() with #GtkGrid."]#-}
tableSetColSpacings ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- spacing
    m ()
tableSetColSpacings _obj spacing = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_table_set_col_spacings _obj' spacing
    touchManagedPtr _obj
    return ()

-- method Table::set_homogeneous
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "homogeneous", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "homogeneous", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_set_homogeneous" gtk_table_set_homogeneous :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    CInt ->                                 -- homogeneous : TBasicType TBoolean
    IO ()

{-# DEPRECATED tableSetHomogeneous ["(Since version 3.4)","Use gtk_grid_set_row_homogeneous() and","    gtk_grid_set_column_homogeneous() with #GtkGrid."]#-}
tableSetHomogeneous ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Bool ->                                 -- homogeneous
    m ()
tableSetHomogeneous _obj homogeneous = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let homogeneous' = (fromIntegral . fromEnum) homogeneous
    gtk_table_set_homogeneous _obj' homogeneous'
    touchManagedPtr _obj
    return ()

-- method Table::set_row_spacing
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "row", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "row", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_set_row_spacing" gtk_table_set_row_spacing :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- row : TBasicType TUInt32
    Word32 ->                               -- spacing : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableSetRowSpacing ["(Since version 3.4)","Use gtk_widget_set_margin_top() and","    gtk_widget_set_margin_bottom() on the widgets contained in the row if","    you need this functionality. #GtkGrid does not support per-row spacing."]#-}
tableSetRowSpacing ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- row
    Word32 ->                               -- spacing
    m ()
tableSetRowSpacing _obj row spacing = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_table_set_row_spacing _obj' row spacing
    touchManagedPtr _obj
    return ()

-- method Table::set_row_spacings
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Gtk" "Table", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "spacing", argType = TBasicType TUInt32, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "gtk_table_set_row_spacings" gtk_table_set_row_spacings :: 
    Ptr Table ->                            -- _obj : TInterface "Gtk" "Table"
    Word32 ->                               -- spacing : TBasicType TUInt32
    IO ()

{-# DEPRECATED tableSetRowSpacings ["(Since version 3.4)","Use gtk_grid_set_row_spacing() with #GtkGrid."]#-}
tableSetRowSpacings ::
    (MonadIO m, TableK a) =>
    a ->                                    -- _obj
    Word32 ->                               -- spacing
    m ()
tableSetRowSpacings _obj spacing = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_table_set_row_spacings _obj' spacing
    touchManagedPtr _obj
    return ()


