
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.WindowAccessible
    ( 

-- * Exported types
    WindowAccessible(..)                    ,
    WindowAccessibleK                       ,
    toWindowAccessible                      ,
    noWindowAccessible                      ,


    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype WindowAccessible = WindowAccessible (ForeignPtr WindowAccessible)
foreign import ccall "gtk_window_accessible_get_type"
    c_gtk_window_accessible_get_type :: IO GType

type instance ParentTypes WindowAccessible = WindowAccessibleParentTypes
type WindowAccessibleParentTypes = '[ContainerAccessible, WidgetAccessible, Accessible, Atk.Object, GObject.Object, Atk.Component, Atk.Window]

instance GObject WindowAccessible where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_gtk_window_accessible_get_type
    

class GObject o => WindowAccessibleK o
instance (GObject o, IsDescendantOf WindowAccessible o) => WindowAccessibleK o

toWindowAccessible :: WindowAccessibleK o => o -> IO WindowAccessible
toWindowAccessible = unsafeCastTo WindowAccessible

noWindowAccessible :: Maybe WindowAccessible
noWindowAccessible = Nothing

type instance AttributeList WindowAccessible = WindowAccessibleAttributeList
type WindowAccessibleAttributeList = ('[ '("accessible-component-layer", Atk.ObjectAccessibleComponentLayerPropertyInfo), '("accessible-component-mdi-zorder", Atk.ObjectAccessibleComponentMdiZorderPropertyInfo), '("accessible-description", Atk.ObjectAccessibleDescriptionPropertyInfo), '("accessible-hypertext-nlinks", Atk.ObjectAccessibleHypertextNlinksPropertyInfo), '("accessible-name", Atk.ObjectAccessibleNamePropertyInfo), '("accessible-parent", Atk.ObjectAccessibleParentPropertyInfo), '("accessible-role", Atk.ObjectAccessibleRolePropertyInfo), '("accessible-table-caption", Atk.ObjectAccessibleTableCaptionPropertyInfo), '("accessible-table-caption-object", Atk.ObjectAccessibleTableCaptionObjectPropertyInfo), '("accessible-table-column-description", Atk.ObjectAccessibleTableColumnDescriptionPropertyInfo), '("accessible-table-column-header", Atk.ObjectAccessibleTableColumnHeaderPropertyInfo), '("accessible-table-row-description", Atk.ObjectAccessibleTableRowDescriptionPropertyInfo), '("accessible-table-row-header", Atk.ObjectAccessibleTableRowHeaderPropertyInfo), '("accessible-table-summary", Atk.ObjectAccessibleTableSummaryPropertyInfo), '("accessible-value", Atk.ObjectAccessibleValuePropertyInfo), '("widget", AccessibleWidgetPropertyInfo)] :: [(Symbol, *)])

type instance SignalList WindowAccessible = WindowAccessibleSignalList
type WindowAccessibleSignalList = ('[ '("activate", Atk.WindowActivateSignalInfo), '("active-descendant-changed", Atk.ObjectActiveDescendantChangedSignalInfo), '("bounds-changed", Atk.ComponentBoundsChangedSignalInfo), '("children-changed", Atk.ObjectChildrenChangedSignalInfo), '("create", Atk.WindowCreateSignalInfo), '("deactivate", Atk.WindowDeactivateSignalInfo), '("destroy", Atk.WindowDestroySignalInfo), '("focus-event", Atk.ObjectFocusEventSignalInfo), '("maximize", Atk.WindowMaximizeSignalInfo), '("minimize", Atk.WindowMinimizeSignalInfo), '("move", Atk.WindowMoveSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("property-change", Atk.ObjectPropertyChangeSignalInfo), '("resize", Atk.WindowResizeSignalInfo), '("restore", Atk.WindowRestoreSignalInfo), '("state-change", Atk.ObjectStateChangeSignalInfo), '("visible-data-changed", Atk.ObjectVisibleDataChangedSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])


